"""Типы для LLM библиотеки"""

from typing import Type, TypeAlias, Union

# Собираем типы динамически в зависимости от доступных провайдеров
_llm_client_instances = []
_llm_client_classes = []

# OpenAI
try:
    from langchain_openai import ChatOpenAI

    _llm_client_instances.append(ChatOpenAI)
    _llm_client_classes.append(Type[ChatOpenAI])
except ImportError:
    pass

# GigaChat
try:
    from langchain_gigachat import GigaChat

    _llm_client_instances.append(GigaChat)
    _llm_client_classes.append(Type[GigaChat])
except ImportError:
    pass

# Anthropic
try:
    from langchain_anthropic import ChatAnthropic

    _llm_client_instances.append(ChatAnthropic)
    _llm_client_classes.append(Type[ChatAnthropic])
except ImportError:
    pass

# Google
try:
    from langchain_google_genai import ChatGoogleGenerativeAI

    _llm_client_instances.append(ChatGoogleGenerativeAI)
    _llm_client_classes.append(Type[ChatGoogleGenerativeAI])
except ImportError:
    pass

# XAI
try:
    from langchain_xai import ChatXAI

    _llm_client_instances.append(ChatXAI)
    _llm_client_classes.append(Type[ChatXAI])
except ImportError:
    pass

# DeepSeek
try:
    from langchain_deepseek import ChatDeepSeek

    _llm_client_instances.append(ChatDeepSeek)
    _llm_client_classes.append(Type[ChatDeepSeek])
except ImportError:
    pass

# Cerebras
try:
    from langchain_cerebras import ChatCerebras

    _llm_client_instances.append(ChatCerebras)
    _llm_client_classes.append(Type[ChatCerebras])
except ImportError:
    pass

if _llm_client_instances:
    LLMClientInstance: TypeAlias = Union[*_llm_client_instances]  # type: ignore


if _llm_client_classes:
    LLMClientClass: TypeAlias = Union[*_llm_client_classes]  # type: ignore



from langchain_cerebras import ChatCerebras

from llm.direction import TokenDirection
from llm.providers._base import BaseProvider, ModelConfig
from llm.test_connections import TestConnections
from llm.token_counters import TokenCounterFactory


class CerebrasProvider(BaseProvider):
    """Провайдер для моделей Cerebras"""

    @property
    def name(self) -> str:
        return 'Cerebras'

    def get_models(self) -> dict[str, ModelConfig]:
        """Возвращает конфигурации всех моделей Cerebras"""
        return {
            'gpt-oss-120b': ModelConfig(
                client_class=ChatCerebras,
                token_counter=TokenCounterFactory().create_cerebas_counter(),
                test_connection=TestConnections().cerebras,
                pricing={
                    TokenDirection.ENCODE: 0.25 / 1_000_000,
                    TokenDirection.DECODE: 0.69 / 1_000_000,
                },
            ),
            'qwen-3-32b': ModelConfig(
                client_class=ChatCerebras,
                token_counter=TokenCounterFactory().create_cerebas_counter(),
                test_connection=TestConnections().cerebras,
                pricing={
                    TokenDirection.ENCODE: 0.40 / 1_000_000,
                    TokenDirection.DECODE: 0.80 / 1_000_000,
                },
            ),
            'llama-4-scout-17b-16e-instruct': ModelConfig(
                client_class=ChatCerebras,
                token_counter=TokenCounterFactory().create_cerebas_counter(),
                test_connection=TestConnections().cerebras,
                pricing={
                    TokenDirection.ENCODE: 0.65 / 1_000_000,
                    TokenDirection.DECODE: 0.85 / 1_000_000,
                },
            ),
            'llama-4-maverick-17b-128e-instruct': ModelConfig(
                client_class=ChatCerebras,
                token_counter=TokenCounterFactory().create_cerebas_counter(),
                test_connection=TestConnections().cerebras,
                pricing={
                    TokenDirection.ENCODE: 0.20 / 1_000_000,
                    TokenDirection.DECODE: 0.60 / 1_000_000,
                },
            ),
        }



from langchain_openai import ChatOpenAI

from llm.direction import TokenDirection
from llm.moderations import ModerationPrompt
from llm.providers._base import BaseProvider, ModelConfig
from llm.test_connections import TestConnections
from llm.token_counters import TokenCounterFactory


class OpenAIProvider(BaseProvider):
    """Провайдер для моделей OpenAI"""

    @property
    def name(self) -> str:
        return 'OpenAI'

    def get_models(self) -> dict[str, ModelConfig]:
        """Возвращает конфигурации всех моделей OpenAI"""
        return {
            'gpt-5': ModelConfig(
                client_class=ChatOpenAI,
                token_counter=TokenCounterFactory().create_openai_counter(),
                moderation=ModerationPrompt().openai,
                test_connection=TestConnections().openai,
                pricing={
                    TokenDirection.ENCODE: 1.25 / 1_000_000,
                    TokenDirection.DECODE: 10.00 / 1_000_000,
                },
            ),
            'gpt-5-mini': ModelConfig(
                client_class=ChatOpenAI,
                token_counter=TokenCounterFactory().create_openai_counter(),
                moderation=ModerationPrompt().openai,
                test_connection=TestConnections().openai,
                pricing={
                    TokenDirection.ENCODE: 0.25 / 1_000_000,
                    TokenDirection.DECODE: 2.00 / 1_000_000,
                },
            ),
            'gpt-5-nano': ModelConfig(
                client_class=ChatOpenAI,
                token_counter=TokenCounterFactory().create_openai_counter(),
                moderation=ModerationPrompt().openai,
                test_connection=TestConnections().openai,
                pricing={
                    TokenDirection.ENCODE: 0.05 / 1_000_000,
                    TokenDirection.DECODE: 0.40 / 1_000_000,
                },
            ),
            'gpt-5-chat-latest': ModelConfig(
                client_class=ChatOpenAI,
                token_counter=TokenCounterFactory().create_openai_counter(),
                moderation=ModerationPrompt().openai,
                test_connection=TestConnections().openai,
                pricing={
                    TokenDirection.ENCODE: 1.25 / 1_000_000,
                    TokenDirection.DECODE: 10.00 / 1_000_000,
                },
            ),
            'gpt-4.1': ModelConfig(
                client_class=ChatOpenAI,
                token_counter=TokenCounterFactory().create_openai_counter(),
                moderation=ModerationPrompt().openai,
                test_connection=TestConnections().openai,
                pricing={
                    TokenDirection.ENCODE: 2.00 / 1_000_000,
                    TokenDirection.DECODE: 8.00 / 1_000_000,
                },
            ),
            'gpt-4.1-mini': ModelConfig(
                client_class=ChatOpenAI,
                token_counter=TokenCounterFactory().create_openai_counter(),
                moderation=ModerationPrompt().openai,
                test_connection=TestConnections().openai,
                pricing={
                    TokenDirection.ENCODE: 0.40 / 1_000_000,
                    TokenDirection.DECODE: 1.60 / 1_000_000,
                },
            ),
            'gpt-4.1-nano': ModelConfig(
                client_class=ChatOpenAI,
                token_counter=TokenCounterFactory().create_openai_counter(),
                moderation=ModerationPrompt().openai,
                test_connection=TestConnections().openai,
                pricing={
                    TokenDirection.ENCODE: 0.10 / 1_000_000,
                    TokenDirection.DECODE: 0.40 / 1_000_000,
                },
            ),
            'gpt-4.5-preview': ModelConfig(
                client_class=ChatOpenAI,
                token_counter=TokenCounterFactory().create_openai_counter(),
                moderation=ModerationPrompt().openai,
                test_connection=TestConnections().openai,
                pricing={
                    TokenDirection.ENCODE: 75.00 / 1_000_000,
                    TokenDirection.DECODE: 150.00 / 1_000_000,
                },
            ),
            'gpt-4o-mini': ModelConfig(
                client_class=ChatOpenAI,
                token_counter=TokenCounterFactory().create_openai_counter(),
                moderation=ModerationPrompt().openai,
                test_connection=TestConnections().openai,
                pricing={
                    TokenDirection.ENCODE: 0.15 / 1_000_000,
                    TokenDirection.DECODE: 0.60 / 1_000_000,
                },
            ),
            'gpt-4o': ModelConfig(
                client_class=ChatOpenAI,
                token_counter=TokenCounterFactory().create_openai_counter(),
                moderation=ModerationPrompt().openai,
                test_connection=TestConnections().openai,
                pricing={
                    TokenDirection.ENCODE: 2.50 / 1_000_000,
                    TokenDirection.DECODE: 10.00 / 1_000_000,
                },
            ),
            'o3-2025-04-16': ModelConfig(
                client_class=ChatOpenAI,
                token_counter=TokenCounterFactory().create_openai_counter(),
                moderation=ModerationPrompt().openai,
                test_connection=TestConnections().openai,
                pricing={
                    TokenDirection.ENCODE: 2.00 / 1_000_000,
                    TokenDirection.DECODE: 8.00 / 1_000_000,
                },
            ),
            'o4-mini-2025-04-16': ModelConfig(
                client_class=ChatOpenAI,
                token_counter=TokenCounterFactory().create_openai_counter(),
                moderation=ModerationPrompt().openai,
                test_connection=TestConnections().openai,
                pricing={
                    TokenDirection.ENCODE: 1.10 / 1_000_000,
                    TokenDirection.DECODE: 4.40 / 1_000_000,
                },
            ),
        }



import asyncio

from example.common_imports import *  # noqa: F403
from llm.service import LLMService


async def test() -> None:
    llm = await LLMService.create(grok_3_mini.to_dict())  # noqa: F405
    result = await llm.ainvoke(message='Сколько будет 2 + 2?')
    print(result)
    print(llm.usage)
    print(llm.usd_rate)
    print(llm.chat_json)


async def main() -> None:
    await test()


if __name__ == '__main__':
    asyncio.run(main())



import importlib
import inspect

from llm.providers._base import BaseProvider, ModelConfig


class ProviderFactory:
    def __init__(self, usd_rate: float, model_name: str) -> None:
        self.usd_rate = usd_rate
        self._provider_classes = self._get_available_providers()
        self._provider: BaseProvider = self._init_provider(model_name)

    def _get_available_providers(self) -> list[type[BaseProvider]]:
        """Получает список доступных классов провайдеров из __init__.py

        Returns:
            list[type[BaseProvider]]: Список классов провайдеров
        """
        provider_classes = []

        try:
            providers_module = importlib.import_module('llm.providers')

            exported_names = getattr(providers_module, '__all__', [])

            for name in exported_names:
                obj = getattr(providers_module, name, None)
                if (
                    obj
                    and inspect.isclass(obj)
                    and issubclass(obj, BaseProvider)
                    and obj != BaseProvider
                ):
                    provider_classes.append(obj)

        except ImportError:
            pass

        return provider_classes

    def _init_provider(self, model_name: str) -> BaseProvider:
        """Инициализирует провайдер для модели

        Args:
            model_name (str): Название модели

        Returns:
            BaseProvider: Инициализированный провайдер
        """
        for provider_class in self._provider_classes:
            provider: BaseProvider = provider_class(self.usd_rate)
            if provider.has_model(model_name):
                return provider

        available_providers = [cls.__name__ for cls in self._provider_classes]
        raise ValueError(
            f'Model {model_name} not found in any available provider. '
            f'Available providers: {available_providers}'
        )

    def get_model_config(self, model_name: str) -> ModelConfig:
        """Получает конфигурацию модели

        Args:
            model_name (str): Название модели

        Returns:
            ModelConfig: Конфигурация модели
        """
        return self._provider.get_model_config(model_name)



import aiohttp
from langchain.schema import BaseMessage

from llm.types import LLMClientInstance


class TokenCounterFactory:
    @staticmethod
    def create_openai_counter():
        """Создает функцию счетчика токенов для OpenAI"""

        async def count_tokens(
            messages: list[BaseMessage],
            model_name: str,
            client: LLMClientInstance | None = None,
        ) -> int:
            """Подсчитывает количество токенов.

            Args:
                messages (list[BaseMessage]): Сообщения
                model_name (str): Название модели
                client (LLMClientInstance | None, optional): Клиент LLM.
                    По умолчанию None.

            Returns:
                int: Количество токенов
            """
            import tiktoken

            try:
                encoding = tiktoken.encoding_for_model(model_name)
            except KeyError:
                encoding = tiktoken.get_encoding('cl100k_base')
            text = ' '.join(str(m.content) for m in messages)
            return len(encoding.encode(text))

        return count_tokens

    @staticmethod
    def create_gigachat_counter():
        """Создает функцию счетчика токенов для GigaChat"""

        async def count_tokens(
            messages: list[BaseMessage],
            model_name: str,
            client: LLMClientInstance | None = None,
        ) -> int:
            """Подсчитывает количество токенов.

            Args:
                messages (list[BaseMessage]): Сообщения
                model_name (str): Название модели
                client (LLMClientInstance | None, optional): Клиент LLM.
                    По умолчанию None.

            Returns:
                int: Количество токенов
            """
            if not client:
                raise ValueError('Client not initialized')

            text = ' '.join(str(m.content) for m in messages)
            response = await client.atokens_count([text], model_name)
            return response[0].tokens

        return count_tokens

    @staticmethod
    def create_anthropic_counter():
        """Создает функцию счетчика токенов для Anthropic"""

        async def count_tokens(
            messages: list[BaseMessage],
            model_name: str,
            client: LLMClientInstance | None = None,
        ) -> int:
            """Подсчитывает количество токенов.

            Args:
                messages (list[BaseMessage]): Сообщения
                model_name (str): Название модели
                client (LLMClientInstance | None, optional): Клиент LLM.
                    По умолчанию None.

            Returns:
                int: Количество токенов
            """
            if not client:
                raise ValueError('Client not initialized')

            return client.get_num_tokens_from_messages(messages)

        return count_tokens

    @staticmethod
    def create_google_counter():
        """Создает функцию счетчика токенов для Google"""

        async def count_tokens(
            messages: list[BaseMessage],
            model_name: str,
            client: LLMClientInstance | None = None,
        ) -> int:
            """Подсчитывает количество токенов.

            Args:
                messages (list[BaseMessage]): Сообщения
                model_name (str): Название модели
                client (LLMClientInstance | None, optional): Клиент LLM.
                    По умолчанию None.

            Returns:
                int: Количество токенов
            """
            if not client:
                raise ValueError('Client not initialized')

            google_api_key = client.google_api_key._secret_value

            url = (
                'https://generativelanguage.googleapis.com/'
                'v1beta/models/{model_name}:countTokens'.format(model_name=model_name)
            )

            headers = {
                'x-goog-api-key': google_api_key,
                'Content-Type': 'application/json',
            }

            text = ' '.join(str(m.content) for m in messages)
            payload = {
                'contents': [
                    {
                        'parts': [
                            {
                                'text': text,
                            }
                        ],
                    },
                ],
            }

            async with aiohttp.ClientSession() as session:
                async with session.post(url, headers=headers, json=payload) as response:
                    data = await response.json()
                    return data['totalTokens']

            return client.get_num_tokens_from_messages(messages)

        return count_tokens

    @staticmethod
    def create_xai_counter():
        """Создает функцию счетчика токенов для xAI"""

        async def count_tokens(
            messages: list[BaseMessage],
            model_name: str,
            client: LLMClientInstance | None = None,
        ) -> int:
            """Подсчитывает количество токенов.

            Args:
                messages (list[BaseMessage]): Сообщения
                model_name (str): Название модели
                client (LLMClientInstance | None, optional): Клиент LLM.
                    По умолчанию None.

            Returns:
                int: Количество токенов
            """
            if not client:
                raise ValueError('Client not initialized')

            x_api_key = client.xai_api_key._secret_value

            url = 'https://api.x.ai/v1/tokenize-text'

            headers = {
                'Authorization': f'Bearer {x_api_key}',
                'Content-Type': 'application/json',
            }

            text = ' '.join(str(m.content) for m in messages)
            payload = {
                'text': text,
                'model': model_name,
            }

            async with aiohttp.ClientSession() as session:
                async with session.post(url, headers=headers, json=payload) as response:
                    data = await response.json()
                    return len(data['token_ids'])

        return count_tokens

    @staticmethod
    def create_deepseek_counter():
        """Создает функцию счетчика токенов для DeepSeek"""

        async def count_tokens(
            messages: list[BaseMessage],
            model_name: str,
            client: LLMClientInstance | None = None,
        ) -> int:
            """Подсчитывает количество токенов.

            Args:
                messages (list[BaseMessage]): Сообщения
                model_name (str): Название модели
                client (LLMClientInstance | None, optional): Клиент LLM.
                    По умолчанию None.

            Returns:
                int: Количество токенов
            """
            if not client:
                raise ValueError('Client not initialized')

            from llm.tokenizer.deepseek.deepseek import DeepSeekTokenizer

            tokenizer = DeepSeekTokenizer()
            text = ' '.join(str(m.content) for m in messages)
            return tokenizer.count_tokens(text)

        return count_tokens

    @staticmethod
    def create_cerebas_counter():
        """Создает функцию счетчика токенов для Cerebas"""

        return TokenCounterFactory.create_openai_counter()

    @staticmethod
    def create_openrouter_counter():
        """Создает функцию счетчика токенов для OpenRouter"""

        return TokenCounterFactory.create_openai_counter()



from typing import Any

from pydantic import BaseModel, ConfigDict


class BaseLLM(BaseModel):
    model_config = ConfigDict(extra='allow')

    model: str
    api_key: str | None = None
    credentials: str | None = None
    scope: str | None = None
    verify_ssl_certs: bool | None = None
    profanity_check: bool | None = None
    base_url: str | None = None

    def to_dict(self, exclude_none: bool = True) -> dict[str, Any]:
        return self.model_dump(exclude_none=exclude_none)



import warnings
from typing import Any

from langchain.schema import BaseMessage

from llm.direction import TokenDirection
from llm.providers._factory import ProviderFactory
from llm.types import LLMClientInstance


class ModelRegistry:
    def __init__(self, usd_rate: float, config: dict[str, Any]) -> None:
        self.client: LLMClientInstance | None = None
        self.config = config
        self.usd_rate = usd_rate
        self.__factory = ProviderFactory(usd_rate, config.get('model'))

    def get_model_config(self, model_name: str):
        """Получает конфигурацию модели"""
        return self.__factory.get_model_config(model_name)

    async def get_tokens(self, model_name: str, messages: list[BaseMessage]) -> int:
        """Получает нужную функцию счетчика токенов и вызывает ее

        Args:
            model_name (str): Название модели
            messages (list[BaseMessage]): Сообщения

        Returns:
            int: Количество токенов
        """
        config = self.get_model_config(model_name)
        return await config.token_counter(messages, model_name, self.client)

    async def get_moderation(
        self,
        model_name: str,
        messages: list[BaseMessage],
    ) -> None:
        """Получает нужную функцию модерации и вызывает ее

        Args:
            model_name (str): Название модели
            messages (list[BaseMessage]): Сообщения
        """
        config = self.get_model_config(model_name)
        if config.moderation is None:
            warnings.warn(f'No moderation for model {model_name}')
            return None
        return await config.moderation(messages, self.client)

    async def get_test_connections(self, model_name: str) -> bool | None:
        """Получает нужную функцию теста соединения и вызывает ее

        Args:
            model_name (str): Название модели
            messages (list[BaseMessage]): Сообщения

        Returns:
            bool | None: True, если соединение работает
        """
        config = self.get_model_config(model_name)
        if config.test_connection is None:
            return None
        return await config.test_connection(self.client)

    def init_client(self) -> LLMClientInstance:
        """Инициализирует клиента LLM

        Returns:
            LLMClientInstance: Клиент LLM
        """
        model_name = self.config.get('model')
        model_config = self.get_model_config(model_name)
        self.client = model_config.client_class(**self.config)
        return self.client

    def get_price(self, model_name: str, direction: TokenDirection) -> float:
        """Получает нужную цену

        Args:
            model_name (str): Название модели
            direction (TokenDirection): Направление

        Returns:
            float: Цена
        """
        config = self.get_model_config(model_name)
        return config.pricing[direction]



"""Тест разных типов схем для with_structured_output"""

import asyncio

from pydantic import BaseModel
from typing_extensions import TypedDict

from example.common_imports import *  # noqa: F403
from llm.service import LLMService


# 1. Pydantic модель
class PydanticAnswer(BaseModel):
    answer: str
    justification: str


# 2. TypedDict
class TypedDictAnswer(TypedDict):
    """Answer with justification"""

    answer: str
    justification: str


# 3. OpenAI function schema
openai_schema = {
    'name': 'AnswerWithJustification',
    'description': 'Answer with justification',
    'parameters': {
        'type': 'object',
        'properties': {
            'answer': {'type': 'string'},
            'justification': {'type': 'string'},
        },
        'required': ['answer'],
    },
}

# 4. JSON Schema
json_schema = {
    'type': 'object',
    'properties': {'answer': {'type': 'string'}, 'justification': {'type': 'string'}},
    'required': ['answer'],
}


async def test_schema_types():
    llm = await LLMService.create(gpt_4o_mini.to_dict())  # noqa: F405
    question = 'Что тяжелее: килограмм железа или килограмм пуха?'

    try:
        # Тест 1: Pydantic модель
        print('=== Тест 1: Pydantic модель ===')
        structured_llm = await llm.with_structured_output(PydanticAnswer)
        result = await structured_llm.ainvoke(message=question)
        print(f'Тип результата: {type(result)}')
        print(f'Результат: {result}')
        print(structured_llm.chat_json)
        print()

        # Тест 2: TypedDict
        print('=== Тест 2: TypedDict ===')
        structured_llm = await llm.with_structured_output(TypedDictAnswer)
        result = await structured_llm.ainvoke(message=question)
        print(f'Тип результата: {type(result)}')
        print(f'Результат: {result}')
        print(structured_llm.chat_json)
        print()

        # Тест 3: OpenAI schema
        print('=== Тест 3: OpenAI schema ===')
        structured_llm = await llm.with_structured_output(openai_schema)
        result = await structured_llm.ainvoke(message=question)
        print(f'Тип результата: {type(result)}')
        print(f'Результат: {result}')
        print(structured_llm.chat_json)
        print()

        # Тест 4: JSON Schema
        print('=== Тест 4: JSON Schema ===')
        structured_llm = await llm.with_structured_output(json_schema)
        result = await structured_llm.ainvoke(message=question)
        print(f'Тип результата: {type(result)}')
        print(f'Результат: {result}')
        print(structured_llm.chat_json)

    except Exception as e:
        print(f'Ошибка: {e}')


if __name__ == '__main__':
    asyncio.run(test_schema_types())



from langchain_deepseek import ChatDeepSeek

from llm.direction import TokenDirection
from llm.providers._base import BaseProvider, ModelConfig
from llm.test_connections import TestConnections
from llm.token_counters import TokenCounterFactory


class DeepSeekProvider(BaseProvider):
    """Провайдер для моделей DeepSeek"""

    @property
    def name(self) -> str:
        return 'DeepSeek'

    def get_models(self) -> dict[str, ModelConfig]:
        """Возвращает конфигурации всех моделей DeepSeek"""
        return {
            'deepseek-chat': ModelConfig(
                client_class=ChatDeepSeek,
                token_counter=TokenCounterFactory().create_deepseek_counter(),
                test_connection=TestConnections().deepseek,
                pricing={
                    TokenDirection.ENCODE: 0.27 / 1_000_000,
                    TokenDirection.DECODE: 1.10 / 1_000_000,
                },
            ),
            'deepseek-reasoner': ModelConfig(
                client_class=ChatDeepSeek,
                token_counter=TokenCounterFactory().create_deepseek_counter(),
                test_connection=TestConnections().deepseek,
                pricing={
                    TokenDirection.ENCODE: 0.55 / 1_000_000,
                    TokenDirection.DECODE: 2.19 / 1_000_000,
                },
            ),
        }



import os

from dotenv import load_dotenv

from llm.constructor import BaseLLM

load_dotenv()


CHAT_GPT__KEY = os.getenv('CHAT_GPT__KEY')
GIGACHAT__KEY = os.getenv('GIGACHAT__KEY')
ANTHROPIC__KEY = os.getenv('ANTHROPIC__KEY')
GEMINI__KEY = os.getenv('GEMINI__KEY')
XAI__KEY = os.getenv('XAI__KEY')
DEEPSEEK__KEY = os.getenv('DEEPSEEK__KEY')
CEREBAS__KEY = os.getenv('CEREBAS__KEY')
OPENROUTER__KEY = os.getenv('OPENROUTER__KEY')

gpt_5 = BaseLLM(
    model='gpt-5',
    api_key=CHAT_GPT__KEY,
)

gpt_5_mini = BaseLLM(
    model='gpt-5-mini',
    api_key=CHAT_GPT__KEY,
)

gpt_5_nano = BaseLLM(
    model='gpt-5-nano',
    api_key=CHAT_GPT__KEY,
)

gpt_5_chat_latest = BaseLLM(
    model='gpt-5-chat-latest',
    api_key=CHAT_GPT__KEY,
)

gpt_4_1 = BaseLLM(
    model='gpt-4.1',
    api_key=CHAT_GPT__KEY,
)

gpt_4_1_mini = BaseLLM(
    model='gpt-4.1-mini',
    api_key=CHAT_GPT__KEY,
)

gpt_4_1_nano = BaseLLM(
    model='gpt-4.1-nano',
    api_key=CHAT_GPT__KEY,
)

gpt_4_5_preview = BaseLLM(
    model='gpt-4.5-preview',
    api_key=CHAT_GPT__KEY,
)

gpt_4o_mini = BaseLLM(
    model='gpt-4o-mini',
    api_key=CHAT_GPT__KEY,
)

gpt_4o = BaseLLM(
    model='gpt-4o',
    api_key=CHAT_GPT__KEY,
)

o3_2025_04_16 = BaseLLM(
    model='o3-2025-04-16',
    api_key=CHAT_GPT__KEY,
)

o4_mini_2025_04_16 = BaseLLM(
    model='o4-mini-2025-04-16',
    api_key=CHAT_GPT__KEY,
)

giga_chat = BaseLLM(
    model='GigaChat',
    credentials=GIGACHAT__KEY,
    scope='GIGACHAT_API_CORP',
    verify_ssl_certs=False,
    profanity_check=False,
)

giga_chat_2 = BaseLLM(
    model='GigaChat-2',
    credentials=GIGACHAT__KEY,
    scope='GIGACHAT_API_CORP',
    verify_ssl_certs=False,
    profanity_check=False,
)

giga_chat_pro = BaseLLM(
    model='GigaChat-Pro',
    credentials=GIGACHAT__KEY,
    scope='GIGACHAT_API_CORP',
    verify_ssl_certs=False,
    profanity_check=False,
)

giga_chat_2_pro = BaseLLM(
    model='GigaChat-2-Pro',
    credentials=GIGACHAT__KEY,
    scope='GIGACHAT_API_CORP',
    verify_ssl_certs=False,
    profanity_check=False,
)

giga_chat_max = BaseLLM(
    model='GigaChat-Max',
    credentials=GIGACHAT__KEY,
    scope='GIGACHAT_API_CORP',
    verify_ssl_certs=False,
    profanity_check=False,
)

giga_chat_2_max = BaseLLM(
    model='GigaChat-2-Max',
    credentials=GIGACHAT__KEY,
    scope='GIGACHAT_API_CORP',
    verify_ssl_certs=False,
    profanity_check=False,
)

claude_3_5_haiku = BaseLLM(
    model='claude-3-5-haiku-latest',
    api_key=ANTHROPIC__KEY,
)

claude_3_7_sonnet = BaseLLM(
    model='claude-3-7-sonnet-latest',
    api_key=ANTHROPIC__KEY,
)

claude_opus_4 = BaseLLM(
    model='claude-opus-4-0',
    api_key=ANTHROPIC__KEY,
)

claude_sonnet_4 = BaseLLM(
    model='claude-sonnet-4-0',
    api_key=ANTHROPIC__KEY,
)

gemini_2_0_flash_001 = BaseLLM(
    model='gemini-2.0-flash-001',
    api_key=GEMINI__KEY,
)

gemini_2_5_flash = BaseLLM(
    model='gemini-2.5-flash',
    api_key=GEMINI__KEY,
)

gemini_2_5_pro = BaseLLM(
    model='gemini-2.5-pro-preview-06-05',
    api_key=GEMINI__KEY,
)

grok_3_mini = BaseLLM(
    model='grok-3-mini',
    api_key=XAI__KEY,
)

grok_3 = BaseLLM(
    model='grok-3',
    api_key=XAI__KEY,
)

grok_3_fast = BaseLLM(
    model='grok-3-fast',
    api_key=XAI__KEY,
)

deepseek_chat = BaseLLM(
    model='deepseek-chat',
    api_key=DEEPSEEK__KEY,
)

deepseek_reasoner = BaseLLM(
    model='deepseek-reasoner',
    api_key=DEEPSEEK__KEY,
)

gpt_oss_120b = BaseLLM(
    model='gpt-oss-120b',
    api_key=CEREBAS__KEY,
)

qwen_3_32b = BaseLLM(
    model='qwen-3-32b',
    api_key=CEREBAS__KEY,
)

llama_4_scout_17b_16e_instruct = BaseLLM(
    model='llama-4-scout-17b-16e-instruct',
    api_key=CEREBAS__KEY,
)

llama_4_maverick_17b_128e_instruct = BaseLLM(
    model='llama-4-maverick-17b-128e-instruct',
    api_key=CEREBAS__KEY,
)

openrouter = BaseLLM(
    model='openai/gpt-4o',
    api_key=OPENROUTER__KEY,
)



import json
import os

import requests
from dotenv import load_dotenv

load_dotenv()

OPENROUTER__KEY = os.getenv('OPENROUTER__KEY')

response = requests.get(
    'https://openrouter.ai/api/v1/models',
    headers={'Authorization': f'Bearer {OPENROUTER__KEY}'},
)

data = json.loads(response.text)

code = ''
for i in data['data']:
    model_name = i['id']
    price_input = i['pricing']['prompt']
    price_output = i['pricing']['completion']

    code += (
        f'"{model_name}": ModelConfig(\n'
        f'    client_class=OpenRouterAI,\n'
        f'    token_counter=TokenCounterFactory().create_openrouter_counter(),\n'
        f'    test_connection=TestConnections().openrouter,\n'
        f'    pricing=\n'
        f'    {{\n'
        f'        TokenDirection.ENCODE: {price_input},\n'
        f'        TokenDirection.DECODE: {price_output},\n'
        f'    }},\n'
        f'),\n'
    )


with open('./result_openrouter.txt', 'w', encoding='utf-8') as file:
    file.write(code)



# Общие импорты для всех примеров
from example.llm_config import (
    claude_3_5_haiku,  # noqa: F401
    claude_3_7_sonnet,  # noqa: F401
    claude_opus_4,  # noqa: F401
    claude_sonnet_4,  # noqa: F401
    deepseek_chat,  # noqa: F401
    deepseek_reasoner,  # noqa: F401
    gemini_2_0_flash_001,  # noqa: F401
    gemini_2_5_flash,  # noqa: F401
    gemini_2_5_pro,  # noqa: F401
    giga_chat,  # noqa: F401
    giga_chat_2,  # noqa: F401
    giga_chat_2_max,  # noqa: F401
    giga_chat_2_pro,  # noqa: F401
    giga_chat_max,  # noqa: F401
    giga_chat_pro,  # noqa: F401
    gpt_4_1,  # noqa: F401
    gpt_4_1_mini,  # noqa: F401
    gpt_4_1_nano,  # noqa: F401
    gpt_4_5_preview,  # noqa: F401
    gpt_4o,  # noqa: F401
    gpt_4o_mini,  # noqa: F401
    gpt_5,  # noqa: F401
    gpt_5_chat_latest,  # noqa: F401
    gpt_5_mini,  # noqa: F401
    gpt_5_nano,  # noqa: F401
    gpt_oss_120b,  # noqa: F401
    grok_3,  # noqa: F401
    grok_3_fast,  # noqa: F401
    grok_3_mini,  # noqa: F401
    llama_4_maverick_17b_128e_instruct,  # noqa: F401
    llama_4_scout_17b_16e_instruct,  # noqa: F401
    o3_2025_04_16,  # noqa: F401
    o4_mini_2025_04_16,  # noqa: F401
    openrouter,  # noqa: F401
    qwen_3_32b,  # noqa: F401
)



# ruff: noqa: E501
from functools import partial

from langchain_openai import ChatOpenAI

from llm.direction import TokenDirection
from llm.providers._base import BaseProvider, ModelConfig
from llm.test_connections import TestConnections
from llm.token_counters import TokenCounterFactory

OpenRouterAI = partial(ChatOpenAI, base_url='https://openrouter.ai/api/v1')


class OpenRouterProvider(BaseProvider):
    """Провайдер для моделей OpenRouter"""

    @property
    def name(self) -> str:
        return 'OpenRouter'

    def get_models(self) -> dict[str, ModelConfig]:
        """Возвращает конфигурации всех моделей OpenRouter"""
        return {
            'x-ai/grok-code-fast-1': ModelConfig(
                client_class=OpenRouterAI,
                token_counter=TokenCounterFactory().create_openrouter_counter(),
                test_connection=TestConnections().openrouter,
                pricing={
                    TokenDirection.ENCODE: 0.0000002,
                    TokenDirection.DECODE: 0.0000015,
                },
            ),
            'nousresearch/hermes-4-70b': ModelConfig(
                client_class=OpenRouterAI,
                token_counter=TokenCounterFactory().create_openrouter_counter(),
                test_connection=TestConnections().openrouter,
                pricing={
                    TokenDirection.ENCODE: 0.00000009329544,
                    TokenDirection.DECODE: 0.0000003733632,
                },
            ),
            'nousresearch/hermes-4-405b': ModelConfig(
                client_class=OpenRouterAI,
                token_counter=TokenCounterFactory().create_openrouter_counter(),
                test_connection=TestConnections().openrouter,
                pricing={
                    TokenDirection.ENCODE: 0.0000001999188,
                    TokenDirection.DECODE: 0.000000800064,
                },
            ),
            'google/gemini-2.5-flash-image-preview:free': ModelConfig(
                client_class=OpenRouterAI,
                token_counter=TokenCounterFactory().create_openrouter_counter(),
                test_connection=TestConnections().openrouter,
                pricing={
                    TokenDirection.ENCODE: 0,
                    TokenDirection.DECODE: 0,
                },
            ),
            'google/gemini-2.5-flash-image-preview': ModelConfig(
                client_class=OpenRouterAI,
                token_counter=TokenCounterFactory().create_openrouter_counter(),
                test_connection=TestConnections().openrouter,
                pricing={
                    TokenDirection.ENCODE: 0.0000003,
                    TokenDirection.DECODE: 0.0000025,
                },
            ),
            'deepseek/deepseek-chat-v3.1': ModelConfig(
                client_class=OpenRouterAI,
                token_counter=TokenCounterFactory().create_openrouter_counter(),
                test_connection=TestConnections().openrouter,
                pricing={
                    TokenDirection.ENCODE: 0.0000002,
                    TokenDirection.DECODE: 0.0000008,
                },
            ),
            'deepseek/deepseek-v3.1-base': ModelConfig(
                client_class=OpenRouterAI,
                token_counter=TokenCounterFactory().create_openrouter_counter(),
                test_connection=TestConnections().openrouter,
                pricing={
                    TokenDirection.ENCODE: 0.0000002,
                    TokenDirection.DECODE: 0.0000008,
                },
            ),
            'openai/gpt-4o-audio-preview': ModelConfig(
                client_class=OpenRouterAI,
                token_counter=TokenCounterFactory().create_openrouter_counter(),
                test_connection=TestConnections().openrouter,
                pricing={
                    TokenDirection.ENCODE: 0.0000025,
                    TokenDirection.DECODE: 0.00001,
                },
            ),
            'mistralai/mistral-medium-3.1': ModelConfig(
                client_class=OpenRouterAI,
                token_counter=TokenCounterFactory().create_openrouter_counter(),
                test_connection=TestConnections().openrouter,
                pricing={
                    TokenDirection.ENCODE: 0.0000004,
                    TokenDirection.DECODE: 0.000002,
                },
            ),
            'baidu/ernie-4.5-21b-a3b': ModelConfig(
                client_class=OpenRouterAI,
                token_counter=TokenCounterFactory().create_openrouter_counter(),
                test_connection=TestConnections().openrouter,
                pricing={
                    TokenDirection.ENCODE: 0.00000007,
                    TokenDirection.DECODE: 0.00000028,
                },
            ),
            'baidu/ernie-4.5-vl-28b-a3b': ModelConfig(
                client_class=OpenRouterAI,
                token_counter=TokenCounterFactory().create_openrouter_counter(),
                test_connection=TestConnections().openrouter,
                pricing={
                    TokenDirection.ENCODE: 0.00000014,
                    TokenDirection.DECODE: 0.00000056,
                },
            ),
            'z-ai/glm-4.5v': ModelConfig(
                client_class=OpenRouterAI,
                token_counter=TokenCounterFactory().create_openrouter_counter(),
                test_connection=TestConnections().openrouter,
                pricing={
                    TokenDirection.ENCODE: 0.0000005,
                    TokenDirection.DECODE: 0.0000018,
                },
            ),
            'ai21/jamba-mini-1.7': ModelConfig(
                client_class=OpenRouterAI,
                token_counter=TokenCounterFactory().create_openrouter_counter(),
                test_connection=TestConnections().openrouter,
                pricing={
                    TokenDirection.ENCODE: 0.0000002,
                    TokenDirection.DECODE: 0.0000004,
                },
            ),
            'ai21/jamba-large-1.7': ModelConfig(
                client_class=OpenRouterAI,
                token_counter=TokenCounterFactory().create_openrouter_counter(),
                test_connection=TestConnections().openrouter,
                pricing={
                    TokenDirection.ENCODE: 0.000002,
                    TokenDirection.DECODE: 0.000008,
                },
            ),
            'openai/gpt-5-chat': ModelConfig(
                client_class=OpenRouterAI,
                token_counter=TokenCounterFactory().create_openrouter_counter(),
                test_connection=TestConnections().openrouter,
                pricing={
                    TokenDirection.ENCODE: 0.00000125,
                    TokenDirection.DECODE: 0.00001,
                },
            ),
            'openai/gpt-5': ModelConfig(
                client_class=OpenRouterAI,
                token_counter=TokenCounterFactory().create_openrouter_counter(),
                test_connection=TestConnections().openrouter,
                pricing={
                    TokenDirection.ENCODE: 0.00000125,
                    TokenDirection.DECODE: 0.00001,
                },
            ),
            'openai/gpt-5-mini': ModelConfig(
                client_class=OpenRouterAI,
                token_counter=TokenCounterFactory().create_openrouter_counter(),
                test_connection=TestConnections().openrouter,
                pricing={
                    TokenDirection.ENCODE: 0.00000025,
                    TokenDirection.DECODE: 0.000002,
                },
            ),
            'openai/gpt-5-nano': ModelConfig(
                client_class=OpenRouterAI,
                token_counter=TokenCounterFactory().create_openrouter_counter(),
                test_connection=TestConnections().openrouter,
                pricing={
                    TokenDirection.ENCODE: 0.00000005,
                    TokenDirection.DECODE: 0.0000004,
                },
            ),
            'openai/gpt-oss-120b': ModelConfig(
                client_class=OpenRouterAI,
                token_counter=TokenCounterFactory().create_openrouter_counter(),
                test_connection=TestConnections().openrouter,
                pricing={
                    TokenDirection.ENCODE: 0.000000072,
                    TokenDirection.DECODE: 0.00000028,
                },
            ),
            'openai/gpt-oss-20b:free': ModelConfig(
                client_class=OpenRouterAI,
                token_counter=TokenCounterFactory().create_openrouter_counter(),
                test_connection=TestConnections().openrouter,
                pricing={
                    TokenDirection.ENCODE: 0,
                    TokenDirection.DECODE: 0,
                },
            ),
            'openai/gpt-oss-20b': ModelConfig(
                client_class=OpenRouterAI,
                token_counter=TokenCounterFactory().create_openrouter_counter(),
                test_connection=TestConnections().openrouter,
                pricing={
                    TokenDirection.ENCODE: 0.00000004,
                    TokenDirection.DECODE: 0.00000015,
                },
            ),
            'anthropic/claude-opus-4.1': ModelConfig(
                client_class=OpenRouterAI,
                token_counter=TokenCounterFactory().create_openrouter_counter(),
                test_connection=TestConnections().openrouter,
                pricing={
                    TokenDirection.ENCODE: 0.000015,
                    TokenDirection.DECODE: 0.000075,
                },
            ),
            'mistralai/codestral-2508': ModelConfig(
                client_class=OpenRouterAI,
                token_counter=TokenCounterFactory().create_openrouter_counter(),
                test_connection=TestConnections().openrouter,
                pricing={
                    TokenDirection.ENCODE: 0.0000003,
                    TokenDirection.DECODE: 0.0000009,
                },
            ),
            'qwen/qwen3-30b-a3b-instruct-2507': ModelConfig(
                client_class=OpenRouterAI,
                token_counter=TokenCounterFactory().create_openrouter_counter(),
                test_connection=TestConnections().openrouter,
                pricing={
                    TokenDirection.ENCODE: 0.0000001,
                    TokenDirection.DECODE: 0.0000003,
                },
            ),
            'z-ai/glm-4.5': ModelConfig(
                client_class=OpenRouterAI,
                token_counter=TokenCounterFactory().create_openrouter_counter(),
                test_connection=TestConnections().openrouter,
                pricing={
                    TokenDirection.ENCODE: 0.0000001999188,
                    TokenDirection.DECODE: 0.000000800064,
                },
            ),
            'z-ai/glm-4.5-air:free': ModelConfig(
                client_class=OpenRouterAI,
                token_counter=TokenCounterFactory().create_openrouter_counter(),
                test_connection=TestConnections().openrouter,
                pricing={
                    TokenDirection.ENCODE: 0,
                    TokenDirection.DECODE: 0,
                },
            ),
            'z-ai/glm-4.5-air': ModelConfig(
                client_class=OpenRouterAI,
                token_counter=TokenCounterFactory().create_openrouter_counter(),
                test_connection=TestConnections().openrouter,
                pricing={
                    TokenDirection.ENCODE: 0.0000002,
                    TokenDirection.DECODE: 0.0000011,
                },
            ),
            'qwen/qwen3-235b-a22b-thinking-2507': ModelConfig(
                client_class=OpenRouterAI,
                token_counter=TokenCounterFactory().create_openrouter_counter(),
                test_connection=TestConnections().openrouter,
                pricing={
                    TokenDirection.ENCODE: 0.000000077968332,
                    TokenDirection.DECODE: 0.00000031202496,
                },
            ),
            'z-ai/glm-4-32b': ModelConfig(
                client_class=OpenRouterAI,
                token_counter=TokenCounterFactory().create_openrouter_counter(),
                test_connection=TestConnections().openrouter,
                pricing={
                    TokenDirection.ENCODE: 0.0000001,
                    TokenDirection.DECODE: 0.0000001,
                },
            ),
            'qwen/qwen3-coder:free': ModelConfig(
                client_class=OpenRouterAI,
                token_counter=TokenCounterFactory().create_openrouter_counter(),
                test_connection=TestConnections().openrouter,
                pricing={
                    TokenDirection.ENCODE: 0,
                    TokenDirection.DECODE: 0,
                },
            ),
            'qwen/qwen3-coder': ModelConfig(
                client_class=OpenRouterAI,
                token_counter=TokenCounterFactory().create_openrouter_counter(),
                test_connection=TestConnections().openrouter,
                pricing={
                    TokenDirection.ENCODE: 0.0000002,
                    TokenDirection.DECODE: 0.0000008,
                },
            ),
            'bytedance/ui-tars-1.5-7b': ModelConfig(
                client_class=OpenRouterAI,
                token_counter=TokenCounterFactory().create_openrouter_counter(),
                test_connection=TestConnections().openrouter,
                pricing={
                    TokenDirection.ENCODE: 0.0000001,
                    TokenDirection.DECODE: 0.0000002,
                },
            ),
            'google/gemini-2.5-flash-lite': ModelConfig(
                client_class=OpenRouterAI,
                token_counter=TokenCounterFactory().create_openrouter_counter(),
                test_connection=TestConnections().openrouter,
                pricing={
                    TokenDirection.ENCODE: 0.0000001,
                    TokenDirection.DECODE: 0.0000004,
                },
            ),
            'qwen/qwen3-235b-a22b-2507': ModelConfig(
                client_class=OpenRouterAI,
                token_counter=TokenCounterFactory().create_openrouter_counter(),
                test_connection=TestConnections().openrouter,
                pricing={
                    TokenDirection.ENCODE: 0.000000077968332,
                    TokenDirection.DECODE: 0.00000031202496,
                },
            ),
            'switchpoint/router': ModelConfig(
                client_class=OpenRouterAI,
                token_counter=TokenCounterFactory().create_openrouter_counter(),
                test_connection=TestConnections().openrouter,
                pricing={
                    TokenDirection.ENCODE: 0.00000085,
                    TokenDirection.DECODE: 0.0000034,
                },
            ),
            'moonshotai/kimi-k2:free': ModelConfig(
                client_class=OpenRouterAI,
                token_counter=TokenCounterFactory().create_openrouter_counter(),
                test_connection=TestConnections().openrouter,
                pricing={
                    TokenDirection.ENCODE: 0,
                    TokenDirection.DECODE: 0,
                },
            ),
            'moonshotai/kimi-k2': ModelConfig(
                client_class=OpenRouterAI,
                token_counter=TokenCounterFactory().create_openrouter_counter(),
                test_connection=TestConnections().openrouter,
                pricing={
                    TokenDirection.ENCODE: 0.00000014,
                    TokenDirection.DECODE: 0.00000249,
                },
            ),
            'thudm/glm-4.1v-9b-thinking': ModelConfig(
                client_class=OpenRouterAI,
                token_counter=TokenCounterFactory().create_openrouter_counter(),
                test_connection=TestConnections().openrouter,
                pricing={
                    TokenDirection.ENCODE: 0.000000035,
                    TokenDirection.DECODE: 0.000000138,
                },
            ),
            'mistralai/devstral-medium': ModelConfig(
                client_class=OpenRouterAI,
                token_counter=TokenCounterFactory().create_openrouter_counter(),
                test_connection=TestConnections().openrouter,
                pricing={
                    TokenDirection.ENCODE: 0.0000004,
                    TokenDirection.DECODE: 0.000002,
                },
            ),
            'mistralai/devstral-small': ModelConfig(
                client_class=OpenRouterAI,
                token_counter=TokenCounterFactory().create_openrouter_counter(),
                test_connection=TestConnections().openrouter,
                pricing={
                    TokenDirection.ENCODE: 0.00000007,
                    TokenDirection.DECODE: 0.00000028,
                },
            ),
            'cognitivecomputations/dolphin-mistral-24b-venice-edition:free': ModelConfig(
                client_class=OpenRouterAI,
                token_counter=TokenCounterFactory().create_openrouter_counter(),
                test_connection=TestConnections().openrouter,
                pricing={
                    TokenDirection.ENCODE: 0,
                    TokenDirection.DECODE: 0,
                },
            ),
            'x-ai/grok-4': ModelConfig(
                client_class=OpenRouterAI,
                token_counter=TokenCounterFactory().create_openrouter_counter(),
                test_connection=TestConnections().openrouter,
                pricing={
                    TokenDirection.ENCODE: 0.000003,
                    TokenDirection.DECODE: 0.000015,
                },
            ),
            'google/gemma-3n-e2b-it:free': ModelConfig(
                client_class=OpenRouterAI,
                token_counter=TokenCounterFactory().create_openrouter_counter(),
                test_connection=TestConnections().openrouter,
                pricing={
                    TokenDirection.ENCODE: 0,
                    TokenDirection.DECODE: 0,
                },
            ),
            'tencent/hunyuan-a13b-instruct:free': ModelConfig(
                client_class=OpenRouterAI,
                token_counter=TokenCounterFactory().create_openrouter_counter(),
                test_connection=TestConnections().openrouter,
                pricing={
                    TokenDirection.ENCODE: 0,
                    TokenDirection.DECODE: 0,
                },
            ),
            'tencent/hunyuan-a13b-instruct': ModelConfig(
                client_class=OpenRouterAI,
                token_counter=TokenCounterFactory().create_openrouter_counter(),
                test_connection=TestConnections().openrouter,
                pricing={
                    TokenDirection.ENCODE: 0.00000003,
                    TokenDirection.DECODE: 0.00000003,
                },
            ),
            'tngtech/deepseek-r1t2-chimera:free': ModelConfig(
                client_class=OpenRouterAI,
                token_counter=TokenCounterFactory().create_openrouter_counter(),
                test_connection=TestConnections().openrouter,
                pricing={
                    TokenDirection.ENCODE: 0,
                    TokenDirection.DECODE: 0,
                },
            ),
            'morph/morph-v3-large': ModelConfig(
                client_class=OpenRouterAI,
                token_counter=TokenCounterFactory().create_openrouter_counter(),
                test_connection=TestConnections().openrouter,
                pricing={
                    TokenDirection.ENCODE: 0.0000009,
                    TokenDirection.DECODE: 0.0000019,
                },
            ),
            'morph/morph-v3-fast': ModelConfig(
                client_class=OpenRouterAI,
                token_counter=TokenCounterFactory().create_openrouter_counter(),
                test_connection=TestConnections().openrouter,
                pricing={
                    TokenDirection.ENCODE: 0.0000009,
                    TokenDirection.DECODE: 0.0000019,
                },
            ),
            'baidu/ernie-4.5-vl-424b-a47b': ModelConfig(
                client_class=OpenRouterAI,
                token_counter=TokenCounterFactory().create_openrouter_counter(),
                test_connection=TestConnections().openrouter,
                pricing={
                    TokenDirection.ENCODE: 0.00000042,
                    TokenDirection.DECODE: 0.00000125,
                },
            ),
            'baidu/ernie-4.5-300b-a47b': ModelConfig(
                client_class=OpenRouterAI,
                token_counter=TokenCounterFactory().create_openrouter_counter(),
                test_connection=TestConnections().openrouter,
                pricing={
                    TokenDirection.ENCODE: 0.00000028,
                    TokenDirection.DECODE: 0.0000011,
                },
            ),
            'thedrummer/anubis-70b-v1.1': ModelConfig(
                client_class=OpenRouterAI,
                token_counter=TokenCounterFactory().create_openrouter_counter(),
                test_connection=TestConnections().openrouter,
                pricing={
                    TokenDirection.ENCODE: 0.0000004,
                    TokenDirection.DECODE: 0.0000007,
                },
            ),
            'inception/mercury': ModelConfig(
                client_class=OpenRouterAI,
                token_counter=TokenCounterFactory().create_openrouter_counter(),
                test_connection=TestConnections().openrouter,
                pricing={
                    TokenDirection.ENCODE: 0.00000025,
                    TokenDirection.DECODE: 0.000001,
                },
            ),
            'mistralai/mistral-small-3.2-24b-instruct:free': ModelConfig(
                client_class=OpenRouterAI,
                token_counter=TokenCounterFactory().create_openrouter_counter(),
                test_connection=TestConnections().openrouter,
                pricing={
                    TokenDirection.ENCODE: 0,
                    TokenDirection.DECODE: 0,
                },
            ),
            'mistralai/mistral-small-3.2-24b-instruct': ModelConfig(
                client_class=OpenRouterAI,
                token_counter=TokenCounterFactory().create_openrouter_counter(),
                test_connection=TestConnections().openrouter,
                pricing={
                    TokenDirection.ENCODE: 0.00000005,
                    TokenDirection.DECODE: 0.0000001,
                },
            ),
            'minimax/minimax-m1': ModelConfig(
                client_class=OpenRouterAI,
                token_counter=TokenCounterFactory().create_openrouter_counter(),
                test_connection=TestConnections().openrouter,
                pricing={
                    TokenDirection.ENCODE: 0.0000003,
                    TokenDirection.DECODE: 0.00000165,
                },
            ),
            'google/gemini-2.5-flash-lite-preview-06-17': ModelConfig(
                client_class=OpenRouterAI,
                token_counter=TokenCounterFactory().create_openrouter_counter(),
                test_connection=TestConnections().openrouter,
                pricing={
                    TokenDirection.ENCODE: 0.0000001,
                    TokenDirection.DECODE: 0.0000004,
                },
            ),
            'google/gemini-2.5-flash': ModelConfig(
                client_class=OpenRouterAI,
                token_counter=TokenCounterFactory().create_openrouter_counter(),
                test_connection=TestConnections().openrouter,
                pricing={
                    TokenDirection.ENCODE: 0.0000003,
                    TokenDirection.DECODE: 0.0000025,
                },
            ),
            'google/gemini-2.5-pro': ModelConfig(
                client_class=OpenRouterAI,
                token_counter=TokenCounterFactory().create_openrouter_counter(),
                test_connection=TestConnections().openrouter,
                pricing={
                    TokenDirection.ENCODE: 0.00000125,
                    TokenDirection.DECODE: 0.00001,
                },
            ),
            'moonshotai/kimi-dev-72b:free': ModelConfig(
                client_class=OpenRouterAI,
                token_counter=TokenCounterFactory().create_openrouter_counter(),
                test_connection=TestConnections().openrouter,
                pricing={
                    TokenDirection.ENCODE: 0,
                    TokenDirection.DECODE: 0,
                },
            ),
            'openai/o3-pro': ModelConfig(
                client_class=OpenRouterAI,
                token_counter=TokenCounterFactory().create_openrouter_counter(),
                test_connection=TestConnections().openrouter,
                pricing={
                    TokenDirection.ENCODE: 0.00002,
                    TokenDirection.DECODE: 0.00008,
                },
            ),
            'x-ai/grok-3-mini': ModelConfig(
                client_class=OpenRouterAI,
                token_counter=TokenCounterFactory().create_openrouter_counter(),
                test_connection=TestConnections().openrouter,
                pricing={
                    TokenDirection.ENCODE: 0.0000003,
                    TokenDirection.DECODE: 0.0000005,
                },
            ),
            'x-ai/grok-3': ModelConfig(
                client_class=OpenRouterAI,
                token_counter=TokenCounterFactory().create_openrouter_counter(),
                test_connection=TestConnections().openrouter,
                pricing={
                    TokenDirection.ENCODE: 0.000003,
                    TokenDirection.DECODE: 0.000015,
                },
            ),
            'mistralai/magistral-small-2506': ModelConfig(
                client_class=OpenRouterAI,
                token_counter=TokenCounterFactory().create_openrouter_counter(),
                test_connection=TestConnections().openrouter,
                pricing={
                    TokenDirection.ENCODE: 0.0000005,
                    TokenDirection.DECODE: 0.0000015,
                },
            ),
            'mistralai/magistral-medium-2506': ModelConfig(
                client_class=OpenRouterAI,
                token_counter=TokenCounterFactory().create_openrouter_counter(),
                test_connection=TestConnections().openrouter,
                pricing={
                    TokenDirection.ENCODE: 0.000002,
                    TokenDirection.DECODE: 0.000005,
                },
            ),
            'mistralai/magistral-medium-2506:thinking': ModelConfig(
                client_class=OpenRouterAI,
                token_counter=TokenCounterFactory().create_openrouter_counter(),
                test_connection=TestConnections().openrouter,
                pricing={
                    TokenDirection.ENCODE: 0.000002,
                    TokenDirection.DECODE: 0.000005,
                },
            ),
            'google/gemini-2.5-pro-preview': ModelConfig(
                client_class=OpenRouterAI,
                token_counter=TokenCounterFactory().create_openrouter_counter(),
                test_connection=TestConnections().openrouter,
                pricing={
                    TokenDirection.ENCODE: 0.00000125,
                    TokenDirection.DECODE: 0.00001,
                },
            ),
            'deepseek/deepseek-r1-0528-qwen3-8b:free': ModelConfig(
                client_class=OpenRouterAI,
                token_counter=TokenCounterFactory().create_openrouter_counter(),
                test_connection=TestConnections().openrouter,
                pricing={
                    TokenDirection.ENCODE: 0,
                    TokenDirection.DECODE: 0,
                },
            ),
            'deepseek/deepseek-r1-0528-qwen3-8b': ModelConfig(
                client_class=OpenRouterAI,
                token_counter=TokenCounterFactory().create_openrouter_counter(),
                test_connection=TestConnections().openrouter,
                pricing={
                    TokenDirection.ENCODE: 0.00000001,
                    TokenDirection.DECODE: 0.00000002,
                },
            ),
            'deepseek/deepseek-r1-0528:free': ModelConfig(
                client_class=OpenRouterAI,
                token_counter=TokenCounterFactory().create_openrouter_counter(),
                test_connection=TestConnections().openrouter,
                pricing={
                    TokenDirection.ENCODE: 0,
                    TokenDirection.DECODE: 0,
                },
            ),
            'deepseek/deepseek-r1-0528': ModelConfig(
                client_class=OpenRouterAI,
                token_counter=TokenCounterFactory().create_openrouter_counter(),
                test_connection=TestConnections().openrouter,
                pricing={
                    TokenDirection.ENCODE: 0.0000001999188,
                    TokenDirection.DECODE: 0.000000800064,
                },
            ),
            'sarvamai/sarvam-m:free': ModelConfig(
                client_class=OpenRouterAI,
                token_counter=TokenCounterFactory().create_openrouter_counter(),
                test_connection=TestConnections().openrouter,
                pricing={
                    TokenDirection.ENCODE: 0,
                    TokenDirection.DECODE: 0,
                },
            ),
            'anthropic/claude-opus-4': ModelConfig(
                client_class=OpenRouterAI,
                token_counter=TokenCounterFactory().create_openrouter_counter(),
                test_connection=TestConnections().openrouter,
                pricing={
                    TokenDirection.ENCODE: 0.000015,
                    TokenDirection.DECODE: 0.000075,
                },
            ),
            'anthropic/claude-sonnet-4': ModelConfig(
                client_class=OpenRouterAI,
                token_counter=TokenCounterFactory().create_openrouter_counter(),
                test_connection=TestConnections().openrouter,
                pricing={
                    TokenDirection.ENCODE: 0.000003,
                    TokenDirection.DECODE: 0.000015,
                },
            ),
            'mistralai/devstral-small-2505:free': ModelConfig(
                client_class=OpenRouterAI,
                token_counter=TokenCounterFactory().create_openrouter_counter(),
                test_connection=TestConnections().openrouter,
                pricing={
                    TokenDirection.ENCODE: 0,
                    TokenDirection.DECODE: 0,
                },
            ),
            'mistralai/devstral-small-2505': ModelConfig(
                client_class=OpenRouterAI,
                token_counter=TokenCounterFactory().create_openrouter_counter(),
                test_connection=TestConnections().openrouter,
                pricing={
                    TokenDirection.ENCODE: 0.00000001999188,
                    TokenDirection.DECODE: 0.0000000800064,
                },
            ),
            'google/gemma-3n-e4b-it:free': ModelConfig(
                client_class=OpenRouterAI,
                token_counter=TokenCounterFactory().create_openrouter_counter(),
                test_connection=TestConnections().openrouter,
                pricing={
                    TokenDirection.ENCODE: 0,
                    TokenDirection.DECODE: 0,
                },
            ),
            'google/gemma-3n-e4b-it': ModelConfig(
                client_class=OpenRouterAI,
                token_counter=TokenCounterFactory().create_openrouter_counter(),
                test_connection=TestConnections().openrouter,
                pricing={
                    TokenDirection.ENCODE: 0.00000002,
                    TokenDirection.DECODE: 0.00000004,
                },
            ),
            'openai/codex-mini': ModelConfig(
                client_class=OpenRouterAI,
                token_counter=TokenCounterFactory().create_openrouter_counter(),
                test_connection=TestConnections().openrouter,
                pricing={
                    TokenDirection.ENCODE: 0.0000015,
                    TokenDirection.DECODE: 0.000006,
                },
            ),
            'meta-llama/llama-3.3-8b-instruct:free': ModelConfig(
                client_class=OpenRouterAI,
                token_counter=TokenCounterFactory().create_openrouter_counter(),
                test_connection=TestConnections().openrouter,
                pricing={
                    TokenDirection.ENCODE: 0,
                    TokenDirection.DECODE: 0,
                },
            ),
            'nousresearch/deephermes-3-mistral-24b-preview': ModelConfig(
                client_class=OpenRouterAI,
                token_counter=TokenCounterFactory().create_openrouter_counter(),
                test_connection=TestConnections().openrouter,
                pricing={
                    TokenDirection.ENCODE: 0.00000009329544,
                    TokenDirection.DECODE: 0.0000003733632,
                },
            ),
            'mistralai/mistral-medium-3': ModelConfig(
                client_class=OpenRouterAI,
                token_counter=TokenCounterFactory().create_openrouter_counter(),
                test_connection=TestConnections().openrouter,
                pricing={
                    TokenDirection.ENCODE: 0.0000004,
                    TokenDirection.DECODE: 0.000002,
                },
            ),
            'google/gemini-2.5-pro-preview-05-06': ModelConfig(
                client_class=OpenRouterAI,
                token_counter=TokenCounterFactory().create_openrouter_counter(),
                test_connection=TestConnections().openrouter,
                pricing={
                    TokenDirection.ENCODE: 0.00000125,
                    TokenDirection.DECODE: 0.00001,
                },
            ),
            'arcee-ai/spotlight': ModelConfig(
                client_class=OpenRouterAI,
                token_counter=TokenCounterFactory().create_openrouter_counter(),
                test_connection=TestConnections().openrouter,
                pricing={
                    TokenDirection.ENCODE: 0.00000018,
                    TokenDirection.DECODE: 0.00000018,
                },
            ),
            'arcee-ai/maestro-reasoning': ModelConfig(
                client_class=OpenRouterAI,
                token_counter=TokenCounterFactory().create_openrouter_counter(),
                test_connection=TestConnections().openrouter,
                pricing={
                    TokenDirection.ENCODE: 0.0000009,
                    TokenDirection.DECODE: 0.0000033,
                },
            ),
            'arcee-ai/virtuoso-large': ModelConfig(
                client_class=OpenRouterAI,
                token_counter=TokenCounterFactory().create_openrouter_counter(),
                test_connection=TestConnections().openrouter,
                pricing={
                    TokenDirection.ENCODE: 0.00000075,
                    TokenDirection.DECODE: 0.0000012,
                },
            ),
            'arcee-ai/coder-large': ModelConfig(
                client_class=OpenRouterAI,
                token_counter=TokenCounterFactory().create_openrouter_counter(),
                test_connection=TestConnections().openrouter,
                pricing={
                    TokenDirection.ENCODE: 0.0000005,
                    TokenDirection.DECODE: 0.0000008,
                },
            ),
            'microsoft/phi-4-reasoning-plus': ModelConfig(
                client_class=OpenRouterAI,
                token_counter=TokenCounterFactory().create_openrouter_counter(),
                test_connection=TestConnections().openrouter,
                pricing={
                    TokenDirection.ENCODE: 0.00000007,
                    TokenDirection.DECODE: 0.00000035,
                },
            ),
            'inception/mercury-coder': ModelConfig(
                client_class=OpenRouterAI,
                token_counter=TokenCounterFactory().create_openrouter_counter(),
                test_connection=TestConnections().openrouter,
                pricing={
                    TokenDirection.ENCODE: 0.00000025,
                    TokenDirection.DECODE: 0.000001,
                },
            ),
            'qwen/qwen3-4b:free': ModelConfig(
                client_class=OpenRouterAI,
                token_counter=TokenCounterFactory().create_openrouter_counter(),
                test_connection=TestConnections().openrouter,
                pricing={
                    TokenDirection.ENCODE: 0,
                    TokenDirection.DECODE: 0,
                },
            ),
            'opengvlab/internvl3-14b': ModelConfig(
                client_class=OpenRouterAI,
                token_counter=TokenCounterFactory().create_openrouter_counter(),
                test_connection=TestConnections().openrouter,
                pricing={
                    TokenDirection.ENCODE: 0.0000002,
                    TokenDirection.DECODE: 0.0000004,
                },
            ),
            'deepseek/deepseek-prover-v2': ModelConfig(
                client_class=OpenRouterAI,
                token_counter=TokenCounterFactory().create_openrouter_counter(),
                test_connection=TestConnections().openrouter,
                pricing={
                    TokenDirection.ENCODE: 0.0000005,
                    TokenDirection.DECODE: 0.00000218,
                },
            ),
            'meta-llama/llama-guard-4-12b': ModelConfig(
                client_class=OpenRouterAI,
                token_counter=TokenCounterFactory().create_openrouter_counter(),
                test_connection=TestConnections().openrouter,
                pricing={
                    TokenDirection.ENCODE: 0.00000018,
                    TokenDirection.DECODE: 0.00000018,
                },
            ),
            'qwen/qwen3-30b-a3b:free': ModelConfig(
                client_class=OpenRouterAI,
                token_counter=TokenCounterFactory().create_openrouter_counter(),
                test_connection=TestConnections().openrouter,
                pricing={
                    TokenDirection.ENCODE: 0,
                    TokenDirection.DECODE: 0,
                },
            ),
            'qwen/qwen3-30b-a3b': ModelConfig(
                client_class=OpenRouterAI,
                token_counter=TokenCounterFactory().create_openrouter_counter(),
                test_connection=TestConnections().openrouter,
                pricing={
                    TokenDirection.ENCODE: 0.00000001999188,
                    TokenDirection.DECODE: 0.0000000800064,
                },
            ),
            'qwen/qwen3-8b:free': ModelConfig(
                client_class=OpenRouterAI,
                token_counter=TokenCounterFactory().create_openrouter_counter(),
                test_connection=TestConnections().openrouter,
                pricing={
                    TokenDirection.ENCODE: 0,
                    TokenDirection.DECODE: 0,
                },
            ),
            'qwen/qwen3-8b': ModelConfig(
                client_class=OpenRouterAI,
                token_counter=TokenCounterFactory().create_openrouter_counter(),
                test_connection=TestConnections().openrouter,
                pricing={
                    TokenDirection.ENCODE: 0.000000035,
                    TokenDirection.DECODE: 0.000000138,
                },
            ),
            'qwen/qwen3-14b:free': ModelConfig(
                client_class=OpenRouterAI,
                token_counter=TokenCounterFactory().create_openrouter_counter(),
                test_connection=TestConnections().openrouter,
                pricing={
                    TokenDirection.ENCODE: 0,
                    TokenDirection.DECODE: 0,
                },
            ),
            'qwen/qwen3-14b': ModelConfig(
                client_class=OpenRouterAI,
                token_counter=TokenCounterFactory().create_openrouter_counter(),
                test_connection=TestConnections().openrouter,
                pricing={
                    TokenDirection.ENCODE: 0.00000006,
                    TokenDirection.DECODE: 0.00000024,
                },
            ),
            'qwen/qwen3-32b': ModelConfig(
                client_class=OpenRouterAI,
                token_counter=TokenCounterFactory().create_openrouter_counter(),
                test_connection=TestConnections().openrouter,
                pricing={
                    TokenDirection.ENCODE: 0.000000017992692,
                    TokenDirection.DECODE: 0.00000007200576,
                },
            ),
            'qwen/qwen3-235b-a22b:free': ModelConfig(
                client_class=OpenRouterAI,
                token_counter=TokenCounterFactory().create_openrouter_counter(),
                test_connection=TestConnections().openrouter,
                pricing={
                    TokenDirection.ENCODE: 0,
                    TokenDirection.DECODE: 0,
                },
            ),
            'qwen/qwen3-235b-a22b': ModelConfig(
                client_class=OpenRouterAI,
                token_counter=TokenCounterFactory().create_openrouter_counter(),
                test_connection=TestConnections().openrouter,
                pricing={
                    TokenDirection.ENCODE: 0.00000013,
                    TokenDirection.DECODE: 0.0000006,
                },
            ),
            'tngtech/deepseek-r1t-chimera:free': ModelConfig(
                client_class=OpenRouterAI,
                token_counter=TokenCounterFactory().create_openrouter_counter(),
                test_connection=TestConnections().openrouter,
                pricing={
                    TokenDirection.ENCODE: 0,
                    TokenDirection.DECODE: 0,
                },
            ),
            'tngtech/deepseek-r1t-chimera': ModelConfig(
                client_class=OpenRouterAI,
                token_counter=TokenCounterFactory().create_openrouter_counter(),
                test_connection=TestConnections().openrouter,
                pricing={
                    TokenDirection.ENCODE: 0.0000001999188,
                    TokenDirection.DECODE: 0.000000800064,
                },
            ),
            'microsoft/mai-ds-r1:free': ModelConfig(
                client_class=OpenRouterAI,
                token_counter=TokenCounterFactory().create_openrouter_counter(),
                test_connection=TestConnections().openrouter,
                pricing={
                    TokenDirection.ENCODE: 0,
                    TokenDirection.DECODE: 0,
                },
            ),
            'microsoft/mai-ds-r1': ModelConfig(
                client_class=OpenRouterAI,
                token_counter=TokenCounterFactory().create_openrouter_counter(),
                test_connection=TestConnections().openrouter,
                pricing={
                    TokenDirection.ENCODE: 0.0000001999188,
                    TokenDirection.DECODE: 0.000000800064,
                },
            ),
            'thudm/glm-z1-32b': ModelConfig(
                client_class=OpenRouterAI,
                token_counter=TokenCounterFactory().create_openrouter_counter(),
                test_connection=TestConnections().openrouter,
                pricing={
                    TokenDirection.ENCODE: 0.00000001999188,
                    TokenDirection.DECODE: 0.0000000800064,
                },
            ),
            'thudm/glm-4-32b': ModelConfig(
                client_class=OpenRouterAI,
                token_counter=TokenCounterFactory().create_openrouter_counter(),
                test_connection=TestConnections().openrouter,
                pricing={
                    TokenDirection.ENCODE: 0.00000055,
                    TokenDirection.DECODE: 0.00000166,
                },
            ),
            'openai/o4-mini-high': ModelConfig(
                client_class=OpenRouterAI,
                token_counter=TokenCounterFactory().create_openrouter_counter(),
                test_connection=TestConnections().openrouter,
                pricing={
                    TokenDirection.ENCODE: 0.0000011,
                    TokenDirection.DECODE: 0.0000044,
                },
            ),
            'openai/o3': ModelConfig(
                client_class=OpenRouterAI,
                token_counter=TokenCounterFactory().create_openrouter_counter(),
                test_connection=TestConnections().openrouter,
                pricing={
                    TokenDirection.ENCODE: 0.000002,
                    TokenDirection.DECODE: 0.000008,
                },
            ),
            'openai/o4-mini': ModelConfig(
                client_class=OpenRouterAI,
                token_counter=TokenCounterFactory().create_openrouter_counter(),
                test_connection=TestConnections().openrouter,
                pricing={
                    TokenDirection.ENCODE: 0.0000011,
                    TokenDirection.DECODE: 0.0000044,
                },
            ),
            'shisa-ai/shisa-v2-llama3.3-70b:free': ModelConfig(
                client_class=OpenRouterAI,
                token_counter=TokenCounterFactory().create_openrouter_counter(),
                test_connection=TestConnections().openrouter,
                pricing={
                    TokenDirection.ENCODE: 0,
                    TokenDirection.DECODE: 0,
                },
            ),
            'shisa-ai/shisa-v2-llama3.3-70b': ModelConfig(
                client_class=OpenRouterAI,
                token_counter=TokenCounterFactory().create_openrouter_counter(),
                test_connection=TestConnections().openrouter,
                pricing={
                    TokenDirection.ENCODE: 0.00000001999188,
                    TokenDirection.DECODE: 0.0000000800064,
                },
            ),
            'openai/gpt-4.1': ModelConfig(
                client_class=OpenRouterAI,
                token_counter=TokenCounterFactory().create_openrouter_counter(),
                test_connection=TestConnections().openrouter,
                pricing={
                    TokenDirection.ENCODE: 0.000002,
                    TokenDirection.DECODE: 0.000008,
                },
            ),
            'openai/gpt-4.1-mini': ModelConfig(
                client_class=OpenRouterAI,
                token_counter=TokenCounterFactory().create_openrouter_counter(),
                test_connection=TestConnections().openrouter,
                pricing={
                    TokenDirection.ENCODE: 0.0000004,
                    TokenDirection.DECODE: 0.0000016,
                },
            ),
            'openai/gpt-4.1-nano': ModelConfig(
                client_class=OpenRouterAI,
                token_counter=TokenCounterFactory().create_openrouter_counter(),
                test_connection=TestConnections().openrouter,
                pricing={
                    TokenDirection.ENCODE: 0.0000001,
                    TokenDirection.DECODE: 0.0000004,
                },
            ),
            'eleutherai/llemma_7b': ModelConfig(
                client_class=OpenRouterAI,
                token_counter=TokenCounterFactory().create_openrouter_counter(),
                test_connection=TestConnections().openrouter,
                pricing={
                    TokenDirection.ENCODE: 0.0000008,
                    TokenDirection.DECODE: 0.0000012,
                },
            ),
            'alfredpros/codellama-7b-instruct-solidity': ModelConfig(
                client_class=OpenRouterAI,
                token_counter=TokenCounterFactory().create_openrouter_counter(),
                test_connection=TestConnections().openrouter,
                pricing={
                    TokenDirection.ENCODE: 0.0000007,
                    TokenDirection.DECODE: 0.0000011,
                },
            ),
            'arliai/qwq-32b-arliai-rpr-v1:free': ModelConfig(
                client_class=OpenRouterAI,
                token_counter=TokenCounterFactory().create_openrouter_counter(),
                test_connection=TestConnections().openrouter,
                pricing={
                    TokenDirection.ENCODE: 0,
                    TokenDirection.DECODE: 0,
                },
            ),
            'arliai/qwq-32b-arliai-rpr-v1': ModelConfig(
                client_class=OpenRouterAI,
                token_counter=TokenCounterFactory().create_openrouter_counter(),
                test_connection=TestConnections().openrouter,
                pricing={
                    TokenDirection.ENCODE: 0.00000001,
                    TokenDirection.DECODE: 0.0000000400032,
                },
            ),
            'agentica-org/deepcoder-14b-preview:free': ModelConfig(
                client_class=OpenRouterAI,
                token_counter=TokenCounterFactory().create_openrouter_counter(),
                test_connection=TestConnections().openrouter,
                pricing={
                    TokenDirection.ENCODE: 0,
                    TokenDirection.DECODE: 0,
                },
            ),
            'agentica-org/deepcoder-14b-preview': ModelConfig(
                client_class=OpenRouterAI,
                token_counter=TokenCounterFactory().create_openrouter_counter(),
                test_connection=TestConnections().openrouter,
                pricing={
                    TokenDirection.ENCODE: 0.000000015,
                    TokenDirection.DECODE: 0.000000015,
                },
            ),
            'moonshotai/kimi-vl-a3b-thinking:free': ModelConfig(
                client_class=OpenRouterAI,
                token_counter=TokenCounterFactory().create_openrouter_counter(),
                test_connection=TestConnections().openrouter,
                pricing={
                    TokenDirection.ENCODE: 0,
                    TokenDirection.DECODE: 0,
                },
            ),
            'moonshotai/kimi-vl-a3b-thinking': ModelConfig(
                client_class=OpenRouterAI,
                token_counter=TokenCounterFactory().create_openrouter_counter(),
                test_connection=TestConnections().openrouter,
                pricing={
                    TokenDirection.ENCODE: 0.00000002498985,
                    TokenDirection.DECODE: 0.000000100008,
                },
            ),
            'x-ai/grok-3-mini-beta': ModelConfig(
                client_class=OpenRouterAI,
                token_counter=TokenCounterFactory().create_openrouter_counter(),
                test_connection=TestConnections().openrouter,
                pricing={
                    TokenDirection.ENCODE: 0.0000003,
                    TokenDirection.DECODE: 0.0000005,
                },
            ),
            'x-ai/grok-3-beta': ModelConfig(
                client_class=OpenRouterAI,
                token_counter=TokenCounterFactory().create_openrouter_counter(),
                test_connection=TestConnections().openrouter,
                pricing={
                    TokenDirection.ENCODE: 0.000003,
                    TokenDirection.DECODE: 0.000015,
                },
            ),
            'nvidia/llama-3.3-nemotron-super-49b-v1': ModelConfig(
                client_class=OpenRouterAI,
                token_counter=TokenCounterFactory().create_openrouter_counter(),
                test_connection=TestConnections().openrouter,
                pricing={
                    TokenDirection.ENCODE: 0.00000013,
                    TokenDirection.DECODE: 0.0000004,
                },
            ),
            'nvidia/llama-3.1-nemotron-ultra-253b-v1:free': ModelConfig(
                client_class=OpenRouterAI,
                token_counter=TokenCounterFactory().create_openrouter_counter(),
                test_connection=TestConnections().openrouter,
                pricing={
                    TokenDirection.ENCODE: 0,
                    TokenDirection.DECODE: 0,
                },
            ),
            'nvidia/llama-3.1-nemotron-ultra-253b-v1': ModelConfig(
                client_class=OpenRouterAI,
                token_counter=TokenCounterFactory().create_openrouter_counter(),
                test_connection=TestConnections().openrouter,
                pricing={
                    TokenDirection.ENCODE: 0.0000006,
                    TokenDirection.DECODE: 0.0000018,
                },
            ),
            'meta-llama/llama-4-maverick:free': ModelConfig(
                client_class=OpenRouterAI,
                token_counter=TokenCounterFactory().create_openrouter_counter(),
                test_connection=TestConnections().openrouter,
                pricing={
                    TokenDirection.ENCODE: 0,
                    TokenDirection.DECODE: 0,
                },
            ),
            'meta-llama/llama-4-maverick': ModelConfig(
                client_class=OpenRouterAI,
                token_counter=TokenCounterFactory().create_openrouter_counter(),
                test_connection=TestConnections().openrouter,
                pricing={
                    TokenDirection.ENCODE: 0.00000015,
                    TokenDirection.DECODE: 0.0000006,
                },
            ),
            'meta-llama/llama-4-scout:free': ModelConfig(
                client_class=OpenRouterAI,
                token_counter=TokenCounterFactory().create_openrouter_counter(),
                test_connection=TestConnections().openrouter,
                pricing={
                    TokenDirection.ENCODE: 0,
                    TokenDirection.DECODE: 0,
                },
            ),
            'meta-llama/llama-4-scout': ModelConfig(
                client_class=OpenRouterAI,
                token_counter=TokenCounterFactory().create_openrouter_counter(),
                test_connection=TestConnections().openrouter,
                pricing={
                    TokenDirection.ENCODE: 0.00000008,
                    TokenDirection.DECODE: 0.0000003,
                },
            ),
            'scb10x/llama3.1-typhoon2-70b-instruct': ModelConfig(
                client_class=OpenRouterAI,
                token_counter=TokenCounterFactory().create_openrouter_counter(),
                test_connection=TestConnections().openrouter,
                pricing={
                    TokenDirection.ENCODE: 0.00000088,
                    TokenDirection.DECODE: 0.00000088,
                },
            ),
            'google/gemini-2.5-pro-exp-03-25': ModelConfig(
                client_class=OpenRouterAI,
                token_counter=TokenCounterFactory().create_openrouter_counter(),
                test_connection=TestConnections().openrouter,
                pricing={
                    TokenDirection.ENCODE: 0,
                    TokenDirection.DECODE: 0,
                },
            ),
            'qwen/qwen2.5-vl-32b-instruct:free': ModelConfig(
                client_class=OpenRouterAI,
                token_counter=TokenCounterFactory().create_openrouter_counter(),
                test_connection=TestConnections().openrouter,
                pricing={
                    TokenDirection.ENCODE: 0,
                    TokenDirection.DECODE: 0,
                },
            ),
            'qwen/qwen2.5-vl-32b-instruct': ModelConfig(
                client_class=OpenRouterAI,
                token_counter=TokenCounterFactory().create_openrouter_counter(),
                test_connection=TestConnections().openrouter,
                pricing={
                    TokenDirection.ENCODE: 0.00000001999188,
                    TokenDirection.DECODE: 0.0000000800064,
                },
            ),
            'deepseek/deepseek-chat-v3-0324:free': ModelConfig(
                client_class=OpenRouterAI,
                token_counter=TokenCounterFactory().create_openrouter_counter(),
                test_connection=TestConnections().openrouter,
                pricing={
                    TokenDirection.ENCODE: 0,
                    TokenDirection.DECODE: 0,
                },
            ),
            'deepseek/deepseek-chat-v3-0324': ModelConfig(
                client_class=OpenRouterAI,
                token_counter=TokenCounterFactory().create_openrouter_counter(),
                test_connection=TestConnections().openrouter,
                pricing={
                    TokenDirection.ENCODE: 0.0000001999188,
                    TokenDirection.DECODE: 0.000000800064,
                },
            ),
            'openai/o1-pro': ModelConfig(
                client_class=OpenRouterAI,
                token_counter=TokenCounterFactory().create_openrouter_counter(),
                test_connection=TestConnections().openrouter,
                pricing={
                    TokenDirection.ENCODE: 0.00015,
                    TokenDirection.DECODE: 0.0006,
                },
            ),
            'mistralai/mistral-small-3.1-24b-instruct:free': ModelConfig(
                client_class=OpenRouterAI,
                token_counter=TokenCounterFactory().create_openrouter_counter(),
                test_connection=TestConnections().openrouter,
                pricing={
                    TokenDirection.ENCODE: 0,
                    TokenDirection.DECODE: 0,
                },
            ),
            'mistralai/mistral-small-3.1-24b-instruct': ModelConfig(
                client_class=OpenRouterAI,
                token_counter=TokenCounterFactory().create_openrouter_counter(),
                test_connection=TestConnections().openrouter,
                pricing={
                    TokenDirection.ENCODE: 0.00000001999188,
                    TokenDirection.DECODE: 0.0000000800064,
                },
            ),
            'google/gemma-3-4b-it:free': ModelConfig(
                client_class=OpenRouterAI,
                token_counter=TokenCounterFactory().create_openrouter_counter(),
                test_connection=TestConnections().openrouter,
                pricing={
                    TokenDirection.ENCODE: 0,
                    TokenDirection.DECODE: 0,
                },
            ),
            'google/gemma-3-4b-it': ModelConfig(
                client_class=OpenRouterAI,
                token_counter=TokenCounterFactory().create_openrouter_counter(),
                test_connection=TestConnections().openrouter,
                pricing={
                    TokenDirection.ENCODE: 0.00000002,
                    TokenDirection.DECODE: 0.00000004,
                },
            ),
            'google/gemma-3-12b-it:free': ModelConfig(
                client_class=OpenRouterAI,
                token_counter=TokenCounterFactory().create_openrouter_counter(),
                test_connection=TestConnections().openrouter,
                pricing={
                    TokenDirection.ENCODE: 0,
                    TokenDirection.DECODE: 0,
                },
            ),
            'google/gemma-3-12b-it': ModelConfig(
                client_class=OpenRouterAI,
                token_counter=TokenCounterFactory().create_openrouter_counter(),
                test_connection=TestConnections().openrouter,
                pricing={
                    TokenDirection.ENCODE: 0.0000000481286,
                    TokenDirection.DECODE: 0.000000192608,
                },
            ),
            'cohere/command-a': ModelConfig(
                client_class=OpenRouterAI,
                token_counter=TokenCounterFactory().create_openrouter_counter(),
                test_connection=TestConnections().openrouter,
                pricing={
                    TokenDirection.ENCODE: 0.000002,
                    TokenDirection.DECODE: 0.000008,
                },
            ),
            'openai/gpt-4o-mini-search-preview': ModelConfig(
                client_class=OpenRouterAI,
                token_counter=TokenCounterFactory().create_openrouter_counter(),
                test_connection=TestConnections().openrouter,
                pricing={
                    TokenDirection.ENCODE: 0.00000015,
                    TokenDirection.DECODE: 0.0000006,
                },
            ),
            'openai/gpt-4o-search-preview': ModelConfig(
                client_class=OpenRouterAI,
                token_counter=TokenCounterFactory().create_openrouter_counter(),
                test_connection=TestConnections().openrouter,
                pricing={
                    TokenDirection.ENCODE: 0.0000025,
                    TokenDirection.DECODE: 0.00001,
                },
            ),
            'rekaai/reka-flash-3:free': ModelConfig(
                client_class=OpenRouterAI,
                token_counter=TokenCounterFactory().create_openrouter_counter(),
                test_connection=TestConnections().openrouter,
                pricing={
                    TokenDirection.ENCODE: 0,
                    TokenDirection.DECODE: 0,
                },
            ),
            'google/gemma-3-27b-it:free': ModelConfig(
                client_class=OpenRouterAI,
                token_counter=TokenCounterFactory().create_openrouter_counter(),
                test_connection=TestConnections().openrouter,
                pricing={
                    TokenDirection.ENCODE: 0,
                    TokenDirection.DECODE: 0,
                },
            ),
            'google/gemma-3-27b-it': ModelConfig(
                client_class=OpenRouterAI,
                token_counter=TokenCounterFactory().create_openrouter_counter(),
                test_connection=TestConnections().openrouter,
                pricing={
                    TokenDirection.ENCODE: 0.0000000666396,
                    TokenDirection.DECODE: 0.000000266688,
                },
            ),
            'thedrummer/anubis-pro-105b-v1': ModelConfig(
                client_class=OpenRouterAI,
                token_counter=TokenCounterFactory().create_openrouter_counter(),
                test_connection=TestConnections().openrouter,
                pricing={
                    TokenDirection.ENCODE: 0.0000005,
                    TokenDirection.DECODE: 0.000001,
                },
            ),
            'thedrummer/skyfall-36b-v2': ModelConfig(
                client_class=OpenRouterAI,
                token_counter=TokenCounterFactory().create_openrouter_counter(),
                test_connection=TestConnections().openrouter,
                pricing={
                    TokenDirection.ENCODE: 0.0000000481286,
                    TokenDirection.DECODE: 0.000000192608,
                },
            ),
            'microsoft/phi-4-multimodal-instruct': ModelConfig(
                client_class=OpenRouterAI,
                token_counter=TokenCounterFactory().create_openrouter_counter(),
                test_connection=TestConnections().openrouter,
                pricing={
                    TokenDirection.ENCODE: 0.00000005,
                    TokenDirection.DECODE: 0.0000001,
                },
            ),
            'perplexity/sonar-reasoning-pro': ModelConfig(
                client_class=OpenRouterAI,
                token_counter=TokenCounterFactory().create_openrouter_counter(),
                test_connection=TestConnections().openrouter,
                pricing={
                    TokenDirection.ENCODE: 0.000002,
                    TokenDirection.DECODE: 0.000008,
                },
            ),
            'perplexity/sonar-pro': ModelConfig(
                client_class=OpenRouterAI,
                token_counter=TokenCounterFactory().create_openrouter_counter(),
                test_connection=TestConnections().openrouter,
                pricing={
                    TokenDirection.ENCODE: 0.000003,
                    TokenDirection.DECODE: 0.000015,
                },
            ),
            'perplexity/sonar-deep-research': ModelConfig(
                client_class=OpenRouterAI,
                token_counter=TokenCounterFactory().create_openrouter_counter(),
                test_connection=TestConnections().openrouter,
                pricing={
                    TokenDirection.ENCODE: 0.000002,
                    TokenDirection.DECODE: 0.000008,
                },
            ),
            'qwen/qwq-32b:free': ModelConfig(
                client_class=OpenRouterAI,
                token_counter=TokenCounterFactory().create_openrouter_counter(),
                test_connection=TestConnections().openrouter,
                pricing={
                    TokenDirection.ENCODE: 0,
                    TokenDirection.DECODE: 0,
                },
            ),
            'qwen/qwq-32b': ModelConfig(
                client_class=OpenRouterAI,
                token_counter=TokenCounterFactory().create_openrouter_counter(),
                test_connection=TestConnections().openrouter,
                pricing={
                    TokenDirection.ENCODE: 0.000000075,
                    TokenDirection.DECODE: 0.00000015,
                },
            ),
            'nousresearch/deephermes-3-llama-3-8b-preview:free': ModelConfig(
                client_class=OpenRouterAI,
                token_counter=TokenCounterFactory().create_openrouter_counter(),
                test_connection=TestConnections().openrouter,
                pricing={
                    TokenDirection.ENCODE: 0,
                    TokenDirection.DECODE: 0,
                },
            ),
            'google/gemini-2.0-flash-lite-001': ModelConfig(
                client_class=OpenRouterAI,
                token_counter=TokenCounterFactory().create_openrouter_counter(),
                test_connection=TestConnections().openrouter,
                pricing={
                    TokenDirection.ENCODE: 0.000000075,
                    TokenDirection.DECODE: 0.0000003,
                },
            ),
            'anthropic/claude-3.7-sonnet': ModelConfig(
                client_class=OpenRouterAI,
                token_counter=TokenCounterFactory().create_openrouter_counter(),
                test_connection=TestConnections().openrouter,
                pricing={
                    TokenDirection.ENCODE: 0.000003,
                    TokenDirection.DECODE: 0.000015,
                },
            ),
            'anthropic/claude-3.7-sonnet:thinking': ModelConfig(
                client_class=OpenRouterAI,
                token_counter=TokenCounterFactory().create_openrouter_counter(),
                test_connection=TestConnections().openrouter,
                pricing={
                    TokenDirection.ENCODE: 0.000003,
                    TokenDirection.DECODE: 0.000015,
                },
            ),
            'perplexity/r1-1776': ModelConfig(
                client_class=OpenRouterAI,
                token_counter=TokenCounterFactory().create_openrouter_counter(),
                test_connection=TestConnections().openrouter,
                pricing={
                    TokenDirection.ENCODE: 0.000002,
                    TokenDirection.DECODE: 0.000008,
                },
            ),
            'mistralai/mistral-saba': ModelConfig(
                client_class=OpenRouterAI,
                token_counter=TokenCounterFactory().create_openrouter_counter(),
                test_connection=TestConnections().openrouter,
                pricing={
                    TokenDirection.ENCODE: 0.0000002,
                    TokenDirection.DECODE: 0.0000006,
                },
            ),
            'cognitivecomputations/dolphin3.0-r1-mistral-24b:free': ModelConfig(
                client_class=OpenRouterAI,
                token_counter=TokenCounterFactory().create_openrouter_counter(),
                test_connection=TestConnections().openrouter,
                pricing={
                    TokenDirection.ENCODE: 0,
                    TokenDirection.DECODE: 0,
                },
            ),
            'cognitivecomputations/dolphin3.0-r1-mistral-24b': ModelConfig(
                client_class=OpenRouterAI,
                token_counter=TokenCounterFactory().create_openrouter_counter(),
                test_connection=TestConnections().openrouter,
                pricing={
                    TokenDirection.ENCODE: 0.00000001,
                    TokenDirection.DECODE: 0.0000000340768,
                },
            ),
            'cognitivecomputations/dolphin3.0-mistral-24b:free': ModelConfig(
                client_class=OpenRouterAI,
                token_counter=TokenCounterFactory().create_openrouter_counter(),
                test_connection=TestConnections().openrouter,
                pricing={
                    TokenDirection.ENCODE: 0,
                    TokenDirection.DECODE: 0,
                },
            ),
            'cognitivecomputations/dolphin3.0-mistral-24b': ModelConfig(
                client_class=OpenRouterAI,
                token_counter=TokenCounterFactory().create_openrouter_counter(),
                test_connection=TestConnections().openrouter,
                pricing={
                    TokenDirection.ENCODE: 0.000000037022,
                    TokenDirection.DECODE: 0.00000014816,
                },
            ),
            'meta-llama/llama-guard-3-8b': ModelConfig(
                client_class=OpenRouterAI,
                token_counter=TokenCounterFactory().create_openrouter_counter(),
                test_connection=TestConnections().openrouter,
                pricing={
                    TokenDirection.ENCODE: 0.00000002,
                    TokenDirection.DECODE: 0.00000006,
                },
            ),
            'openai/o3-mini-high': ModelConfig(
                client_class=OpenRouterAI,
                token_counter=TokenCounterFactory().create_openrouter_counter(),
                test_connection=TestConnections().openrouter,
                pricing={
                    TokenDirection.ENCODE: 0.0000011,
                    TokenDirection.DECODE: 0.0000044,
                },
            ),
            'deepseek/deepseek-r1-distill-llama-8b': ModelConfig(
                client_class=OpenRouterAI,
                token_counter=TokenCounterFactory().create_openrouter_counter(),
                test_connection=TestConnections().openrouter,
                pricing={
                    TokenDirection.ENCODE: 0.00000004,
                    TokenDirection.DECODE: 0.00000004,
                },
            ),
            'google/gemini-2.0-flash-001': ModelConfig(
                client_class=OpenRouterAI,
                token_counter=TokenCounterFactory().create_openrouter_counter(),
                test_connection=TestConnections().openrouter,
                pricing={
                    TokenDirection.ENCODE: 0.0000001,
                    TokenDirection.DECODE: 0.0000004,
                },
            ),
            'qwen/qwen-vl-plus': ModelConfig(
                client_class=OpenRouterAI,
                token_counter=TokenCounterFactory().create_openrouter_counter(),
                test_connection=TestConnections().openrouter,
                pricing={
                    TokenDirection.ENCODE: 0.00000021,
                    TokenDirection.DECODE: 0.00000063,
                },
            ),
            'aion-labs/aion-1.0': ModelConfig(
                client_class=OpenRouterAI,
                token_counter=TokenCounterFactory().create_openrouter_counter(),
                test_connection=TestConnections().openrouter,
                pricing={
                    TokenDirection.ENCODE: 0.000004,
                    TokenDirection.DECODE: 0.000008,
                },
            ),
            'aion-labs/aion-1.0-mini': ModelConfig(
                client_class=OpenRouterAI,
                token_counter=TokenCounterFactory().create_openrouter_counter(),
                test_connection=TestConnections().openrouter,
                pricing={
                    TokenDirection.ENCODE: 0.0000007,
                    TokenDirection.DECODE: 0.0000014,
                },
            ),
            'aion-labs/aion-rp-llama-3.1-8b': ModelConfig(
                client_class=OpenRouterAI,
                token_counter=TokenCounterFactory().create_openrouter_counter(),
                test_connection=TestConnections().openrouter,
                pricing={
                    TokenDirection.ENCODE: 0.0000002,
                    TokenDirection.DECODE: 0.0000002,
                },
            ),
            'qwen/qwen-vl-max': ModelConfig(
                client_class=OpenRouterAI,
                token_counter=TokenCounterFactory().create_openrouter_counter(),
                test_connection=TestConnections().openrouter,
                pricing={
                    TokenDirection.ENCODE: 0.0000008,
                    TokenDirection.DECODE: 0.0000032,
                },
            ),
            'qwen/qwen-turbo': ModelConfig(
                client_class=OpenRouterAI,
                token_counter=TokenCounterFactory().create_openrouter_counter(),
                test_connection=TestConnections().openrouter,
                pricing={
                    TokenDirection.ENCODE: 0.00000005,
                    TokenDirection.DECODE: 0.0000002,
                },
            ),
            'qwen/qwen2.5-vl-72b-instruct:free': ModelConfig(
                client_class=OpenRouterAI,
                token_counter=TokenCounterFactory().create_openrouter_counter(),
                test_connection=TestConnections().openrouter,
                pricing={
                    TokenDirection.ENCODE: 0,
                    TokenDirection.DECODE: 0,
                },
            ),
            'qwen/qwen2.5-vl-72b-instruct': ModelConfig(
                client_class=OpenRouterAI,
                token_counter=TokenCounterFactory().create_openrouter_counter(),
                test_connection=TestConnections().openrouter,
                pricing={
                    TokenDirection.ENCODE: 0.0000000999594,
                    TokenDirection.DECODE: 0.000000400032,
                },
            ),
            'qwen/qwen-plus': ModelConfig(
                client_class=OpenRouterAI,
                token_counter=TokenCounterFactory().create_openrouter_counter(),
                test_connection=TestConnections().openrouter,
                pricing={
                    TokenDirection.ENCODE: 0.0000004,
                    TokenDirection.DECODE: 0.0000012,
                },
            ),
            'qwen/qwen-max': ModelConfig(
                client_class=OpenRouterAI,
                token_counter=TokenCounterFactory().create_openrouter_counter(),
                test_connection=TestConnections().openrouter,
                pricing={
                    TokenDirection.ENCODE: 0.0000016,
                    TokenDirection.DECODE: 0.0000064,
                },
            ),
            'openai/o3-mini': ModelConfig(
                client_class=OpenRouterAI,
                token_counter=TokenCounterFactory().create_openrouter_counter(),
                test_connection=TestConnections().openrouter,
                pricing={
                    TokenDirection.ENCODE: 0.0000011,
                    TokenDirection.DECODE: 0.0000044,
                },
            ),
            'deepseek/deepseek-r1-distill-qwen-1.5b': ModelConfig(
                client_class=OpenRouterAI,
                token_counter=TokenCounterFactory().create_openrouter_counter(),
                test_connection=TestConnections().openrouter,
                pricing={
                    TokenDirection.ENCODE: 0.00000018,
                    TokenDirection.DECODE: 0.00000018,
                },
            ),
            'mistralai/mistral-small-24b-instruct-2501:free': ModelConfig(
                client_class=OpenRouterAI,
                token_counter=TokenCounterFactory().create_openrouter_counter(),
                test_connection=TestConnections().openrouter,
                pricing={
                    TokenDirection.ENCODE: 0,
                    TokenDirection.DECODE: 0,
                },
            ),
            'mistralai/mistral-small-24b-instruct-2501': ModelConfig(
                client_class=OpenRouterAI,
                token_counter=TokenCounterFactory().create_openrouter_counter(),
                test_connection=TestConnections().openrouter,
                pricing={
                    TokenDirection.ENCODE: 0.00000001999188,
                    TokenDirection.DECODE: 0.0000000800064,
                },
            ),
            'deepseek/deepseek-r1-distill-qwen-32b': ModelConfig(
                client_class=OpenRouterAI,
                token_counter=TokenCounterFactory().create_openrouter_counter(),
                test_connection=TestConnections().openrouter,
                pricing={
                    TokenDirection.ENCODE: 0.000000075,
                    TokenDirection.DECODE: 0.00000015,
                },
            ),
            'deepseek/deepseek-r1-distill-qwen-14b:free': ModelConfig(
                client_class=OpenRouterAI,
                token_counter=TokenCounterFactory().create_openrouter_counter(),
                test_connection=TestConnections().openrouter,
                pricing={
                    TokenDirection.ENCODE: 0,
                    TokenDirection.DECODE: 0,
                },
            ),
            'deepseek/deepseek-r1-distill-qwen-14b': ModelConfig(
                client_class=OpenRouterAI,
                token_counter=TokenCounterFactory().create_openrouter_counter(),
                test_connection=TestConnections().openrouter,
                pricing={
                    TokenDirection.ENCODE: 0.00000015,
                    TokenDirection.DECODE: 0.00000015,
                },
            ),
            'perplexity/sonar-reasoning': ModelConfig(
                client_class=OpenRouterAI,
                token_counter=TokenCounterFactory().create_openrouter_counter(),
                test_connection=TestConnections().openrouter,
                pricing={
                    TokenDirection.ENCODE: 0.000001,
                    TokenDirection.DECODE: 0.000005,
                },
            ),
            'perplexity/sonar': ModelConfig(
                client_class=OpenRouterAI,
                token_counter=TokenCounterFactory().create_openrouter_counter(),
                test_connection=TestConnections().openrouter,
                pricing={
                    TokenDirection.ENCODE: 0.000001,
                    TokenDirection.DECODE: 0.000001,
                },
            ),
            'liquid/lfm-7b': ModelConfig(
                client_class=OpenRouterAI,
                token_counter=TokenCounterFactory().create_openrouter_counter(),
                test_connection=TestConnections().openrouter,
                pricing={
                    TokenDirection.ENCODE: 0.00000001,
                    TokenDirection.DECODE: 0.00000001,
                },
            ),
            'liquid/lfm-3b': ModelConfig(
                client_class=OpenRouterAI,
                token_counter=TokenCounterFactory().create_openrouter_counter(),
                test_connection=TestConnections().openrouter,
                pricing={
                    TokenDirection.ENCODE: 0.00000002,
                    TokenDirection.DECODE: 0.00000002,
                },
            ),
            'deepseek/deepseek-r1-distill-llama-70b:free': ModelConfig(
                client_class=OpenRouterAI,
                token_counter=TokenCounterFactory().create_openrouter_counter(),
                test_connection=TestConnections().openrouter,
                pricing={
                    TokenDirection.ENCODE: 0,
                    TokenDirection.DECODE: 0,
                },
            ),
            'deepseek/deepseek-r1-distill-llama-70b': ModelConfig(
                client_class=OpenRouterAI,
                token_counter=TokenCounterFactory().create_openrouter_counter(),
                test_connection=TestConnections().openrouter,
                pricing={
                    TokenDirection.ENCODE: 0.0000000259154,
                    TokenDirection.DECODE: 0.000000103712,
                },
            ),
            'deepseek/deepseek-r1:free': ModelConfig(
                client_class=OpenRouterAI,
                token_counter=TokenCounterFactory().create_openrouter_counter(),
                test_connection=TestConnections().openrouter,
                pricing={
                    TokenDirection.ENCODE: 0,
                    TokenDirection.DECODE: 0,
                },
            ),
            'deepseek/deepseek-r1': ModelConfig(
                client_class=OpenRouterAI,
                token_counter=TokenCounterFactory().create_openrouter_counter(),
                test_connection=TestConnections().openrouter,
                pricing={
                    TokenDirection.ENCODE: 0.0000004,
                    TokenDirection.DECODE: 0.000002,
                },
            ),
            'minimax/minimax-01': ModelConfig(
                client_class=OpenRouterAI,
                token_counter=TokenCounterFactory().create_openrouter_counter(),
                test_connection=TestConnections().openrouter,
                pricing={
                    TokenDirection.ENCODE: 0.0000002,
                    TokenDirection.DECODE: 0.0000011,
                },
            ),
            'mistralai/codestral-2501': ModelConfig(
                client_class=OpenRouterAI,
                token_counter=TokenCounterFactory().create_openrouter_counter(),
                test_connection=TestConnections().openrouter,
                pricing={
                    TokenDirection.ENCODE: 0.0000003,
                    TokenDirection.DECODE: 0.0000009,
                },
            ),
            'microsoft/phi-4': ModelConfig(
                client_class=OpenRouterAI,
                token_counter=TokenCounterFactory().create_openrouter_counter(),
                test_connection=TestConnections().openrouter,
                pricing={
                    TokenDirection.ENCODE: 0.00000006,
                    TokenDirection.DECODE: 0.00000014,
                },
            ),
            'deepseek/deepseek-chat': ModelConfig(
                client_class=OpenRouterAI,
                token_counter=TokenCounterFactory().create_openrouter_counter(),
                test_connection=TestConnections().openrouter,
                pricing={
                    TokenDirection.ENCODE: 0.0000001999188,
                    TokenDirection.DECODE: 0.000000800064,
                },
            ),
            'sao10k/l3.3-euryale-70b': ModelConfig(
                client_class=OpenRouterAI,
                token_counter=TokenCounterFactory().create_openrouter_counter(),
                test_connection=TestConnections().openrouter,
                pricing={
                    TokenDirection.ENCODE: 0.00000065,
                    TokenDirection.DECODE: 0.00000075,
                },
            ),
            'openai/o1': ModelConfig(
                client_class=OpenRouterAI,
                token_counter=TokenCounterFactory().create_openrouter_counter(),
                test_connection=TestConnections().openrouter,
                pricing={
                    TokenDirection.ENCODE: 0.000015,
                    TokenDirection.DECODE: 0.00006,
                },
            ),
            'x-ai/grok-2-vision-1212': ModelConfig(
                client_class=OpenRouterAI,
                token_counter=TokenCounterFactory().create_openrouter_counter(),
                test_connection=TestConnections().openrouter,
                pricing={
                    TokenDirection.ENCODE: 0.000002,
                    TokenDirection.DECODE: 0.00001,
                },
            ),
            'x-ai/grok-2-1212': ModelConfig(
                client_class=OpenRouterAI,
                token_counter=TokenCounterFactory().create_openrouter_counter(),
                test_connection=TestConnections().openrouter,
                pricing={
                    TokenDirection.ENCODE: 0.000002,
                    TokenDirection.DECODE: 0.00001,
                },
            ),
            'cohere/command-r7b-12-2024': ModelConfig(
                client_class=OpenRouterAI,
                token_counter=TokenCounterFactory().create_openrouter_counter(),
                test_connection=TestConnections().openrouter,
                pricing={
                    TokenDirection.ENCODE: 0.0000000375,
                    TokenDirection.DECODE: 0.00000015,
                },
            ),
            'google/gemini-2.0-flash-exp:free': ModelConfig(
                client_class=OpenRouterAI,
                token_counter=TokenCounterFactory().create_openrouter_counter(),
                test_connection=TestConnections().openrouter,
                pricing={
                    TokenDirection.ENCODE: 0,
                    TokenDirection.DECODE: 0,
                },
            ),
            'meta-llama/llama-3.3-70b-instruct:free': ModelConfig(
                client_class=OpenRouterAI,
                token_counter=TokenCounterFactory().create_openrouter_counter(),
                test_connection=TestConnections().openrouter,
                pricing={
                    TokenDirection.ENCODE: 0,
                    TokenDirection.DECODE: 0,
                },
            ),
            'meta-llama/llama-3.3-70b-instruct': ModelConfig(
                client_class=OpenRouterAI,
                token_counter=TokenCounterFactory().create_openrouter_counter(),
                test_connection=TestConnections().openrouter,
                pricing={
                    TokenDirection.ENCODE: 0.000000038,
                    TokenDirection.DECODE: 0.00000012,
                },
            ),
            'amazon/nova-lite-v1': ModelConfig(
                client_class=OpenRouterAI,
                token_counter=TokenCounterFactory().create_openrouter_counter(),
                test_connection=TestConnections().openrouter,
                pricing={
                    TokenDirection.ENCODE: 0.00000006,
                    TokenDirection.DECODE: 0.00000024,
                },
            ),
            'amazon/nova-micro-v1': ModelConfig(
                client_class=OpenRouterAI,
                token_counter=TokenCounterFactory().create_openrouter_counter(),
                test_connection=TestConnections().openrouter,
                pricing={
                    TokenDirection.ENCODE: 0.000000035,
                    TokenDirection.DECODE: 0.00000014,
                },
            ),
            'amazon/nova-pro-v1': ModelConfig(
                client_class=OpenRouterAI,
                token_counter=TokenCounterFactory().create_openrouter_counter(),
                test_connection=TestConnections().openrouter,
                pricing={
                    TokenDirection.ENCODE: 0.0000008,
                    TokenDirection.DECODE: 0.0000032,
                },
            ),
            'qwen/qwq-32b-preview': ModelConfig(
                client_class=OpenRouterAI,
                token_counter=TokenCounterFactory().create_openrouter_counter(),
                test_connection=TestConnections().openrouter,
                pricing={
                    TokenDirection.ENCODE: 0.0000002,
                    TokenDirection.DECODE: 0.0000002,
                },
            ),
            'openai/gpt-4o-2024-11-20': ModelConfig(
                client_class=OpenRouterAI,
                token_counter=TokenCounterFactory().create_openrouter_counter(),
                test_connection=TestConnections().openrouter,
                pricing={
                    TokenDirection.ENCODE: 0.0000025,
                    TokenDirection.DECODE: 0.00001,
                },
            ),
            'mistralai/mistral-large-2411': ModelConfig(
                client_class=OpenRouterAI,
                token_counter=TokenCounterFactory().create_openrouter_counter(),
                test_connection=TestConnections().openrouter,
                pricing={
                    TokenDirection.ENCODE: 0.000002,
                    TokenDirection.DECODE: 0.000006,
                },
            ),
            'mistralai/mistral-large-2407': ModelConfig(
                client_class=OpenRouterAI,
                token_counter=TokenCounterFactory().create_openrouter_counter(),
                test_connection=TestConnections().openrouter,
                pricing={
                    TokenDirection.ENCODE: 0.000002,
                    TokenDirection.DECODE: 0.000006,
                },
            ),
            'mistralai/pixtral-large-2411': ModelConfig(
                client_class=OpenRouterAI,
                token_counter=TokenCounterFactory().create_openrouter_counter(),
                test_connection=TestConnections().openrouter,
                pricing={
                    TokenDirection.ENCODE: 0.000002,
                    TokenDirection.DECODE: 0.000006,
                },
            ),
            'x-ai/grok-vision-beta': ModelConfig(
                client_class=OpenRouterAI,
                token_counter=TokenCounterFactory().create_openrouter_counter(),
                test_connection=TestConnections().openrouter,
                pricing={
                    TokenDirection.ENCODE: 0.000005,
                    TokenDirection.DECODE: 0.000015,
                },
            ),
            'infermatic/mn-inferor-12b': ModelConfig(
                client_class=OpenRouterAI,
                token_counter=TokenCounterFactory().create_openrouter_counter(),
                test_connection=TestConnections().openrouter,
                pricing={
                    TokenDirection.ENCODE: 0.0000006,
                    TokenDirection.DECODE: 0.000001,
                },
            ),
            'qwen/qwen-2.5-coder-32b-instruct:free': ModelConfig(
                client_class=OpenRouterAI,
                token_counter=TokenCounterFactory().create_openrouter_counter(),
                test_connection=TestConnections().openrouter,
                pricing={
                    TokenDirection.ENCODE: 0,
                    TokenDirection.DECODE: 0,
                },
            ),
            'qwen/qwen-2.5-coder-32b-instruct': ModelConfig(
                client_class=OpenRouterAI,
                token_counter=TokenCounterFactory().create_openrouter_counter(),
                test_connection=TestConnections().openrouter,
                pricing={
                    TokenDirection.ENCODE: 0.0000000499797,
                    TokenDirection.DECODE: 0.000000200016,
                },
            ),
            'raifle/sorcererlm-8x22b': ModelConfig(
                client_class=OpenRouterAI,
                token_counter=TokenCounterFactory().create_openrouter_counter(),
                test_connection=TestConnections().openrouter,
                pricing={
                    TokenDirection.ENCODE: 0.0000045,
                    TokenDirection.DECODE: 0.0000045,
                },
            ),
            'thedrummer/unslopnemo-12b': ModelConfig(
                client_class=OpenRouterAI,
                token_counter=TokenCounterFactory().create_openrouter_counter(),
                test_connection=TestConnections().openrouter,
                pricing={
                    TokenDirection.ENCODE: 0.0000004,
                    TokenDirection.DECODE: 0.0000004,
                },
            ),
            'anthropic/claude-3.5-haiku': ModelConfig(
                client_class=OpenRouterAI,
                token_counter=TokenCounterFactory().create_openrouter_counter(),
                test_connection=TestConnections().openrouter,
                pricing={
                    TokenDirection.ENCODE: 0.0000008,
                    TokenDirection.DECODE: 0.000004,
                },
            ),
            'anthropic/claude-3.5-haiku-20241022': ModelConfig(
                client_class=OpenRouterAI,
                token_counter=TokenCounterFactory().create_openrouter_counter(),
                test_connection=TestConnections().openrouter,
                pricing={
                    TokenDirection.ENCODE: 0.0000008,
                    TokenDirection.DECODE: 0.000004,
                },
            ),
            'anthracite-org/magnum-v4-72b': ModelConfig(
                client_class=OpenRouterAI,
                token_counter=TokenCounterFactory().create_openrouter_counter(),
                test_connection=TestConnections().openrouter,
                pricing={
                    TokenDirection.ENCODE: 0.000002,
                    TokenDirection.DECODE: 0.000005,
                },
            ),
            'anthropic/claude-3.5-sonnet': ModelConfig(
                client_class=OpenRouterAI,
                token_counter=TokenCounterFactory().create_openrouter_counter(),
                test_connection=TestConnections().openrouter,
                pricing={
                    TokenDirection.ENCODE: 0.000003,
                    TokenDirection.DECODE: 0.000015,
                },
            ),
            'mistralai/ministral-8b': ModelConfig(
                client_class=OpenRouterAI,
                token_counter=TokenCounterFactory().create_openrouter_counter(),
                test_connection=TestConnections().openrouter,
                pricing={
                    TokenDirection.ENCODE: 0.0000001,
                    TokenDirection.DECODE: 0.0000001,
                },
            ),
            'mistralai/ministral-3b': ModelConfig(
                client_class=OpenRouterAI,
                token_counter=TokenCounterFactory().create_openrouter_counter(),
                test_connection=TestConnections().openrouter,
                pricing={
                    TokenDirection.ENCODE: 0.00000004,
                    TokenDirection.DECODE: 0.00000004,
                },
            ),
            'qwen/qwen-2.5-7b-instruct': ModelConfig(
                client_class=OpenRouterAI,
                token_counter=TokenCounterFactory().create_openrouter_counter(),
                test_connection=TestConnections().openrouter,
                pricing={
                    TokenDirection.ENCODE: 0.00000004,
                    TokenDirection.DECODE: 0.0000001,
                },
            ),
            'nvidia/llama-3.1-nemotron-70b-instruct': ModelConfig(
                client_class=OpenRouterAI,
                token_counter=TokenCounterFactory().create_openrouter_counter(),
                test_connection=TestConnections().openrouter,
                pricing={
                    TokenDirection.ENCODE: 0.00000012,
                    TokenDirection.DECODE: 0.0000003,
                },
            ),
            'inflection/inflection-3-pi': ModelConfig(
                client_class=OpenRouterAI,
                token_counter=TokenCounterFactory().create_openrouter_counter(),
                test_connection=TestConnections().openrouter,
                pricing={
                    TokenDirection.ENCODE: 0.0000025,
                    TokenDirection.DECODE: 0.00001,
                },
            ),
            'inflection/inflection-3-productivity': ModelConfig(
                client_class=OpenRouterAI,
                token_counter=TokenCounterFactory().create_openrouter_counter(),
                test_connection=TestConnections().openrouter,
                pricing={
                    TokenDirection.ENCODE: 0.0000025,
                    TokenDirection.DECODE: 0.00001,
                },
            ),
            'google/gemini-flash-1.5-8b': ModelConfig(
                client_class=OpenRouterAI,
                token_counter=TokenCounterFactory().create_openrouter_counter(),
                test_connection=TestConnections().openrouter,
                pricing={
                    TokenDirection.ENCODE: 0.0000000375,
                    TokenDirection.DECODE: 0.00000015,
                },
            ),
            'anthracite-org/magnum-v2-72b': ModelConfig(
                client_class=OpenRouterAI,
                token_counter=TokenCounterFactory().create_openrouter_counter(),
                test_connection=TestConnections().openrouter,
                pricing={
                    TokenDirection.ENCODE: 0.000003,
                    TokenDirection.DECODE: 0.000003,
                },
            ),
            'thedrummer/rocinante-12b': ModelConfig(
                client_class=OpenRouterAI,
                token_counter=TokenCounterFactory().create_openrouter_counter(),
                test_connection=TestConnections().openrouter,
                pricing={
                    TokenDirection.ENCODE: 0.00000017,
                    TokenDirection.DECODE: 0.00000043,
                },
            ),
            'meta-llama/llama-3.2-1b-instruct': ModelConfig(
                client_class=OpenRouterAI,
                token_counter=TokenCounterFactory().create_openrouter_counter(),
                test_connection=TestConnections().openrouter,
                pricing={
                    TokenDirection.ENCODE: 0.000000005,
                    TokenDirection.DECODE: 0.00000001,
                },
            ),
            'meta-llama/llama-3.2-11b-vision-instruct:free': ModelConfig(
                client_class=OpenRouterAI,
                token_counter=TokenCounterFactory().create_openrouter_counter(),
                test_connection=TestConnections().openrouter,
                pricing={
                    TokenDirection.ENCODE: 0,
                    TokenDirection.DECODE: 0,
                },
            ),
            'meta-llama/llama-3.2-11b-vision-instruct': ModelConfig(
                client_class=OpenRouterAI,
                token_counter=TokenCounterFactory().create_openrouter_counter(),
                test_connection=TestConnections().openrouter,
                pricing={
                    TokenDirection.ENCODE: 0.000000049,
                    TokenDirection.DECODE: 0.000000049,
                },
            ),
            'meta-llama/llama-3.2-3b-instruct:free': ModelConfig(
                client_class=OpenRouterAI,
                token_counter=TokenCounterFactory().create_openrouter_counter(),
                test_connection=TestConnections().openrouter,
                pricing={
                    TokenDirection.ENCODE: 0,
                    TokenDirection.DECODE: 0,
                },
            ),
            'meta-llama/llama-3.2-3b-instruct': ModelConfig(
                client_class=OpenRouterAI,
                token_counter=TokenCounterFactory().create_openrouter_counter(),
                test_connection=TestConnections().openrouter,
                pricing={
                    TokenDirection.ENCODE: 0.000000003,
                    TokenDirection.DECODE: 0.000000006,
                },
            ),
            'meta-llama/llama-3.2-90b-vision-instruct': ModelConfig(
                client_class=OpenRouterAI,
                token_counter=TokenCounterFactory().create_openrouter_counter(),
                test_connection=TestConnections().openrouter,
                pricing={
                    TokenDirection.ENCODE: 0.0000012,
                    TokenDirection.DECODE: 0.0000012,
                },
            ),
            'qwen/qwen-2.5-72b-instruct:free': ModelConfig(
                client_class=OpenRouterAI,
                token_counter=TokenCounterFactory().create_openrouter_counter(),
                test_connection=TestConnections().openrouter,
                pricing={
                    TokenDirection.ENCODE: 0,
                    TokenDirection.DECODE: 0,
                },
            ),
            'qwen/qwen-2.5-72b-instruct': ModelConfig(
                client_class=OpenRouterAI,
                token_counter=TokenCounterFactory().create_openrouter_counter(),
                test_connection=TestConnections().openrouter,
                pricing={
                    TokenDirection.ENCODE: 0.0000000518308,
                    TokenDirection.DECODE: 0.000000207424,
                },
            ),
            'neversleep/llama-3.1-lumimaid-8b': ModelConfig(
                client_class=OpenRouterAI,
                token_counter=TokenCounterFactory().create_openrouter_counter(),
                test_connection=TestConnections().openrouter,
                pricing={
                    TokenDirection.ENCODE: 0.00000009,
                    TokenDirection.DECODE: 0.0000006,
                },
            ),
            'openai/o1-mini': ModelConfig(
                client_class=OpenRouterAI,
                token_counter=TokenCounterFactory().create_openrouter_counter(),
                test_connection=TestConnections().openrouter,
                pricing={
                    TokenDirection.ENCODE: 0.0000011,
                    TokenDirection.DECODE: 0.0000044,
                },
            ),
            'openai/o1-mini-2024-09-12': ModelConfig(
                client_class=OpenRouterAI,
                token_counter=TokenCounterFactory().create_openrouter_counter(),
                test_connection=TestConnections().openrouter,
                pricing={
                    TokenDirection.ENCODE: 0.0000011,
                    TokenDirection.DECODE: 0.0000044,
                },
            ),
            'mistralai/pixtral-12b': ModelConfig(
                client_class=OpenRouterAI,
                token_counter=TokenCounterFactory().create_openrouter_counter(),
                test_connection=TestConnections().openrouter,
                pricing={
                    TokenDirection.ENCODE: 0.0000001,
                    TokenDirection.DECODE: 0.0000001,
                },
            ),
            'cohere/command-r-08-2024': ModelConfig(
                client_class=OpenRouterAI,
                token_counter=TokenCounterFactory().create_openrouter_counter(),
                test_connection=TestConnections().openrouter,
                pricing={
                    TokenDirection.ENCODE: 0.00000015,
                    TokenDirection.DECODE: 0.0000006,
                },
            ),
            'cohere/command-r-plus-08-2024': ModelConfig(
                client_class=OpenRouterAI,
                token_counter=TokenCounterFactory().create_openrouter_counter(),
                test_connection=TestConnections().openrouter,
                pricing={
                    TokenDirection.ENCODE: 0.0000025,
                    TokenDirection.DECODE: 0.00001,
                },
            ),
            'sao10k/l3.1-euryale-70b': ModelConfig(
                client_class=OpenRouterAI,
                token_counter=TokenCounterFactory().create_openrouter_counter(),
                test_connection=TestConnections().openrouter,
                pricing={
                    TokenDirection.ENCODE: 0.00000065,
                    TokenDirection.DECODE: 0.00000075,
                },
            ),
            'qwen/qwen-2.5-vl-7b-instruct': ModelConfig(
                client_class=OpenRouterAI,
                token_counter=TokenCounterFactory().create_openrouter_counter(),
                test_connection=TestConnections().openrouter,
                pricing={
                    TokenDirection.ENCODE: 0.0000002,
                    TokenDirection.DECODE: 0.0000002,
                },
            ),
            'microsoft/phi-3.5-mini-128k-instruct': ModelConfig(
                client_class=OpenRouterAI,
                token_counter=TokenCounterFactory().create_openrouter_counter(),
                test_connection=TestConnections().openrouter,
                pricing={
                    TokenDirection.ENCODE: 0.0000001,
                    TokenDirection.DECODE: 0.0000001,
                },
            ),
            'nousresearch/hermes-3-llama-3.1-70b': ModelConfig(
                client_class=OpenRouterAI,
                token_counter=TokenCounterFactory().create_openrouter_counter(),
                test_connection=TestConnections().openrouter,
                pricing={
                    TokenDirection.ENCODE: 0.0000001,
                    TokenDirection.DECODE: 0.00000028,
                },
            ),
            'nousresearch/hermes-3-llama-3.1-405b': ModelConfig(
                client_class=OpenRouterAI,
                token_counter=TokenCounterFactory().create_openrouter_counter(),
                test_connection=TestConnections().openrouter,
                pricing={
                    TokenDirection.ENCODE: 0.0000007,
                    TokenDirection.DECODE: 0.0000008,
                },
            ),
            'openai/chatgpt-4o-latest': ModelConfig(
                client_class=OpenRouterAI,
                token_counter=TokenCounterFactory().create_openrouter_counter(),
                test_connection=TestConnections().openrouter,
                pricing={
                    TokenDirection.ENCODE: 0.000005,
                    TokenDirection.DECODE: 0.000015,
                },
            ),
            'sao10k/l3-lunaris-8b': ModelConfig(
                client_class=OpenRouterAI,
                token_counter=TokenCounterFactory().create_openrouter_counter(),
                test_connection=TestConnections().openrouter,
                pricing={
                    TokenDirection.ENCODE: 0.00000002,
                    TokenDirection.DECODE: 0.00000005,
                },
            ),
            'openai/gpt-4o-2024-08-06': ModelConfig(
                client_class=OpenRouterAI,
                token_counter=TokenCounterFactory().create_openrouter_counter(),
                test_connection=TestConnections().openrouter,
                pricing={
                    TokenDirection.ENCODE: 0.0000025,
                    TokenDirection.DECODE: 0.00001,
                },
            ),
            'meta-llama/llama-3.1-405b': ModelConfig(
                client_class=OpenRouterAI,
                token_counter=TokenCounterFactory().create_openrouter_counter(),
                test_connection=TestConnections().openrouter,
                pricing={
                    TokenDirection.ENCODE: 0.000002,
                    TokenDirection.DECODE: 0.000002,
                },
            ),
            'meta-llama/llama-3.1-8b-instruct': ModelConfig(
                client_class=OpenRouterAI,
                token_counter=TokenCounterFactory().create_openrouter_counter(),
                test_connection=TestConnections().openrouter,
                pricing={
                    TokenDirection.ENCODE: 0.000000015,
                    TokenDirection.DECODE: 0.00000002,
                },
            ),
            'meta-llama/llama-3.1-70b-instruct': ModelConfig(
                client_class=OpenRouterAI,
                token_counter=TokenCounterFactory().create_openrouter_counter(),
                test_connection=TestConnections().openrouter,
                pricing={
                    TokenDirection.ENCODE: 0.0000001,
                    TokenDirection.DECODE: 0.00000028,
                },
            ),
            'meta-llama/llama-3.1-405b-instruct:free': ModelConfig(
                client_class=OpenRouterAI,
                token_counter=TokenCounterFactory().create_openrouter_counter(),
                test_connection=TestConnections().openrouter,
                pricing={
                    TokenDirection.ENCODE: 0,
                    TokenDirection.DECODE: 0,
                },
            ),
            'meta-llama/llama-3.1-405b-instruct': ModelConfig(
                client_class=OpenRouterAI,
                token_counter=TokenCounterFactory().create_openrouter_counter(),
                test_connection=TestConnections().openrouter,
                pricing={
                    TokenDirection.ENCODE: 0.0000008,
                    TokenDirection.DECODE: 0.0000008,
                },
            ),
            'mistralai/mistral-nemo:free': ModelConfig(
                client_class=OpenRouterAI,
                token_counter=TokenCounterFactory().create_openrouter_counter(),
                test_connection=TestConnections().openrouter,
                pricing={
                    TokenDirection.ENCODE: 0,
                    TokenDirection.DECODE: 0,
                },
            ),
            'mistralai/mistral-nemo': ModelConfig(
                client_class=OpenRouterAI,
                token_counter=TokenCounterFactory().create_openrouter_counter(),
                test_connection=TestConnections().openrouter,
                pricing={
                    TokenDirection.ENCODE: 0.0000000075,
                    TokenDirection.DECODE: 0.00000005,
                },
            ),
            'openai/gpt-4o-mini': ModelConfig(
                client_class=OpenRouterAI,
                token_counter=TokenCounterFactory().create_openrouter_counter(),
                test_connection=TestConnections().openrouter,
                pricing={
                    TokenDirection.ENCODE: 0.00000015,
                    TokenDirection.DECODE: 0.0000006,
                },
            ),
            'openai/gpt-4o-mini-2024-07-18': ModelConfig(
                client_class=OpenRouterAI,
                token_counter=TokenCounterFactory().create_openrouter_counter(),
                test_connection=TestConnections().openrouter,
                pricing={
                    TokenDirection.ENCODE: 0.00000015,
                    TokenDirection.DECODE: 0.0000006,
                },
            ),
            'google/gemma-2-27b-it': ModelConfig(
                client_class=OpenRouterAI,
                token_counter=TokenCounterFactory().create_openrouter_counter(),
                test_connection=TestConnections().openrouter,
                pricing={
                    TokenDirection.ENCODE: 0.00000065,
                    TokenDirection.DECODE: 0.00000065,
                },
            ),
            'google/gemma-2-9b-it:free': ModelConfig(
                client_class=OpenRouterAI,
                token_counter=TokenCounterFactory().create_openrouter_counter(),
                test_connection=TestConnections().openrouter,
                pricing={
                    TokenDirection.ENCODE: 0,
                    TokenDirection.DECODE: 0,
                },
            ),
            'google/gemma-2-9b-it': ModelConfig(
                client_class=OpenRouterAI,
                token_counter=TokenCounterFactory().create_openrouter_counter(),
                test_connection=TestConnections().openrouter,
                pricing={
                    TokenDirection.ENCODE: 0.00000001,
                    TokenDirection.DECODE: 0.0000000100008,
                },
            ),
            'anthropic/claude-3.5-sonnet-20240620': ModelConfig(
                client_class=OpenRouterAI,
                token_counter=TokenCounterFactory().create_openrouter_counter(),
                test_connection=TestConnections().openrouter,
                pricing={
                    TokenDirection.ENCODE: 0.000003,
                    TokenDirection.DECODE: 0.000015,
                },
            ),
            'sao10k/l3-euryale-70b': ModelConfig(
                client_class=OpenRouterAI,
                token_counter=TokenCounterFactory().create_openrouter_counter(),
                test_connection=TestConnections().openrouter,
                pricing={
                    TokenDirection.ENCODE: 0.00000148,
                    TokenDirection.DECODE: 0.00000148,
                },
            ),
            'cognitivecomputations/dolphin-mixtral-8x22b': ModelConfig(
                client_class=OpenRouterAI,
                token_counter=TokenCounterFactory().create_openrouter_counter(),
                test_connection=TestConnections().openrouter,
                pricing={
                    TokenDirection.ENCODE: 0.0000009,
                    TokenDirection.DECODE: 0.0000009,
                },
            ),
            'qwen/qwen-2-72b-instruct': ModelConfig(
                client_class=OpenRouterAI,
                token_counter=TokenCounterFactory().create_openrouter_counter(),
                test_connection=TestConnections().openrouter,
                pricing={
                    TokenDirection.ENCODE: 0.0000009,
                    TokenDirection.DECODE: 0.0000009,
                },
            ),
            'mistralai/mistral-7b-instruct-v0.3': ModelConfig(
                client_class=OpenRouterAI,
                token_counter=TokenCounterFactory().create_openrouter_counter(),
                test_connection=TestConnections().openrouter,
                pricing={
                    TokenDirection.ENCODE: 0.000000028,
                    TokenDirection.DECODE: 0.000000054,
                },
            ),
            'mistralai/mistral-7b-instruct:free': ModelConfig(
                client_class=OpenRouterAI,
                token_counter=TokenCounterFactory().create_openrouter_counter(),
                test_connection=TestConnections().openrouter,
                pricing={
                    TokenDirection.ENCODE: 0,
                    TokenDirection.DECODE: 0,
                },
            ),
            'mistralai/mistral-7b-instruct': ModelConfig(
                client_class=OpenRouterAI,
                token_counter=TokenCounterFactory().create_openrouter_counter(),
                test_connection=TestConnections().openrouter,
                pricing={
                    TokenDirection.ENCODE: 0.000000028,
                    TokenDirection.DECODE: 0.000000054,
                },
            ),
            'nousresearch/hermes-2-pro-llama-3-8b': ModelConfig(
                client_class=OpenRouterAI,
                token_counter=TokenCounterFactory().create_openrouter_counter(),
                test_connection=TestConnections().openrouter,
                pricing={
                    TokenDirection.ENCODE: 0.000000025,
                    TokenDirection.DECODE: 0.00000004,
                },
            ),
            'microsoft/phi-3-mini-128k-instruct': ModelConfig(
                client_class=OpenRouterAI,
                token_counter=TokenCounterFactory().create_openrouter_counter(),
                test_connection=TestConnections().openrouter,
                pricing={
                    TokenDirection.ENCODE: 0.0000001,
                    TokenDirection.DECODE: 0.0000001,
                },
            ),
            'microsoft/phi-3-medium-128k-instruct': ModelConfig(
                client_class=OpenRouterAI,
                token_counter=TokenCounterFactory().create_openrouter_counter(),
                test_connection=TestConnections().openrouter,
                pricing={
                    TokenDirection.ENCODE: 0.000001,
                    TokenDirection.DECODE: 0.000001,
                },
            ),
            'neversleep/llama-3-lumimaid-70b': ModelConfig(
                client_class=OpenRouterAI,
                token_counter=TokenCounterFactory().create_openrouter_counter(),
                test_connection=TestConnections().openrouter,
                pricing={
                    TokenDirection.ENCODE: 0.000004,
                    TokenDirection.DECODE: 0.000006,
                },
            ),
            'google/gemini-flash-1.5': ModelConfig(
                client_class=OpenRouterAI,
                token_counter=TokenCounterFactory().create_openrouter_counter(),
                test_connection=TestConnections().openrouter,
                pricing={
                    TokenDirection.ENCODE: 0.000000075,
                    TokenDirection.DECODE: 0.0000003,
                },
            ),
            'openai/gpt-4o': ModelConfig(
                client_class=OpenRouterAI,
                token_counter=TokenCounterFactory().create_openrouter_counter(),
                test_connection=TestConnections().openrouter,
                pricing={
                    TokenDirection.ENCODE: 0.0000025,
                    TokenDirection.DECODE: 0.00001,
                },
            ),
            'openai/gpt-4o:extended': ModelConfig(
                client_class=OpenRouterAI,
                token_counter=TokenCounterFactory().create_openrouter_counter(),
                test_connection=TestConnections().openrouter,
                pricing={
                    TokenDirection.ENCODE: 0.000006,
                    TokenDirection.DECODE: 0.000018,
                },
            ),
            'meta-llama/llama-guard-2-8b': ModelConfig(
                client_class=OpenRouterAI,
                token_counter=TokenCounterFactory().create_openrouter_counter(),
                test_connection=TestConnections().openrouter,
                pricing={
                    TokenDirection.ENCODE: 0.0000002,
                    TokenDirection.DECODE: 0.0000002,
                },
            ),
            'openai/gpt-4o-2024-05-13': ModelConfig(
                client_class=OpenRouterAI,
                token_counter=TokenCounterFactory().create_openrouter_counter(),
                test_connection=TestConnections().openrouter,
                pricing={
                    TokenDirection.ENCODE: 0.000005,
                    TokenDirection.DECODE: 0.000015,
                },
            ),
            'meta-llama/llama-3-70b-instruct': ModelConfig(
                client_class=OpenRouterAI,
                token_counter=TokenCounterFactory().create_openrouter_counter(),
                test_connection=TestConnections().openrouter,
                pricing={
                    TokenDirection.ENCODE: 0.0000003,
                    TokenDirection.DECODE: 0.0000004,
                },
            ),
            'meta-llama/llama-3-8b-instruct': ModelConfig(
                client_class=OpenRouterAI,
                token_counter=TokenCounterFactory().create_openrouter_counter(),
                test_connection=TestConnections().openrouter,
                pricing={
                    TokenDirection.ENCODE: 0.00000003,
                    TokenDirection.DECODE: 0.00000006,
                },
            ),
            'mistralai/mixtral-8x22b-instruct': ModelConfig(
                client_class=OpenRouterAI,
                token_counter=TokenCounterFactory().create_openrouter_counter(),
                test_connection=TestConnections().openrouter,
                pricing={
                    TokenDirection.ENCODE: 0.0000009,
                    TokenDirection.DECODE: 0.0000009,
                },
            ),
            'microsoft/wizardlm-2-8x22b': ModelConfig(
                client_class=OpenRouterAI,
                token_counter=TokenCounterFactory().create_openrouter_counter(),
                test_connection=TestConnections().openrouter,
                pricing={
                    TokenDirection.ENCODE: 0.00000048,
                    TokenDirection.DECODE: 0.00000048,
                },
            ),
            'google/gemini-pro-1.5': ModelConfig(
                client_class=OpenRouterAI,
                token_counter=TokenCounterFactory().create_openrouter_counter(),
                test_connection=TestConnections().openrouter,
                pricing={
                    TokenDirection.ENCODE: 0.00000125,
                    TokenDirection.DECODE: 0.000005,
                },
            ),
            'openai/gpt-4-turbo': ModelConfig(
                client_class=OpenRouterAI,
                token_counter=TokenCounterFactory().create_openrouter_counter(),
                test_connection=TestConnections().openrouter,
                pricing={
                    TokenDirection.ENCODE: 0.00001,
                    TokenDirection.DECODE: 0.00003,
                },
            ),
            'cohere/command-r-plus': ModelConfig(
                client_class=OpenRouterAI,
                token_counter=TokenCounterFactory().create_openrouter_counter(),
                test_connection=TestConnections().openrouter,
                pricing={
                    TokenDirection.ENCODE: 0.000003,
                    TokenDirection.DECODE: 0.000015,
                },
            ),
            'cohere/command-r-plus-04-2024': ModelConfig(
                client_class=OpenRouterAI,
                token_counter=TokenCounterFactory().create_openrouter_counter(),
                test_connection=TestConnections().openrouter,
                pricing={
                    TokenDirection.ENCODE: 0.000003,
                    TokenDirection.DECODE: 0.000015,
                },
            ),
            'sophosympatheia/midnight-rose-70b': ModelConfig(
                client_class=OpenRouterAI,
                token_counter=TokenCounterFactory().create_openrouter_counter(),
                test_connection=TestConnections().openrouter,
                pricing={
                    TokenDirection.ENCODE: 0.0000008,
                    TokenDirection.DECODE: 0.0000008,
                },
            ),
            'cohere/command': ModelConfig(
                client_class=OpenRouterAI,
                token_counter=TokenCounterFactory().create_openrouter_counter(),
                test_connection=TestConnections().openrouter,
                pricing={
                    TokenDirection.ENCODE: 0.000001,
                    TokenDirection.DECODE: 0.000002,
                },
            ),
            'cohere/command-r': ModelConfig(
                client_class=OpenRouterAI,
                token_counter=TokenCounterFactory().create_openrouter_counter(),
                test_connection=TestConnections().openrouter,
                pricing={
                    TokenDirection.ENCODE: 0.0000005,
                    TokenDirection.DECODE: 0.0000015,
                },
            ),
            'anthropic/claude-3-haiku': ModelConfig(
                client_class=OpenRouterAI,
                token_counter=TokenCounterFactory().create_openrouter_counter(),
                test_connection=TestConnections().openrouter,
                pricing={
                    TokenDirection.ENCODE: 0.00000025,
                    TokenDirection.DECODE: 0.00000125,
                },
            ),
            'anthropic/claude-3-opus': ModelConfig(
                client_class=OpenRouterAI,
                token_counter=TokenCounterFactory().create_openrouter_counter(),
                test_connection=TestConnections().openrouter,
                pricing={
                    TokenDirection.ENCODE: 0.000015,
                    TokenDirection.DECODE: 0.000075,
                },
            ),
            'cohere/command-r-03-2024': ModelConfig(
                client_class=OpenRouterAI,
                token_counter=TokenCounterFactory().create_openrouter_counter(),
                test_connection=TestConnections().openrouter,
                pricing={
                    TokenDirection.ENCODE: 0.0000005,
                    TokenDirection.DECODE: 0.0000015,
                },
            ),
            'mistralai/mistral-large': ModelConfig(
                client_class=OpenRouterAI,
                token_counter=TokenCounterFactory().create_openrouter_counter(),
                test_connection=TestConnections().openrouter,
                pricing={
                    TokenDirection.ENCODE: 0.000002,
                    TokenDirection.DECODE: 0.000006,
                },
            ),
            'openai/gpt-4-turbo-preview': ModelConfig(
                client_class=OpenRouterAI,
                token_counter=TokenCounterFactory().create_openrouter_counter(),
                test_connection=TestConnections().openrouter,
                pricing={
                    TokenDirection.ENCODE: 0.00001,
                    TokenDirection.DECODE: 0.00003,
                },
            ),
            'openai/gpt-3.5-turbo-0613': ModelConfig(
                client_class=OpenRouterAI,
                token_counter=TokenCounterFactory().create_openrouter_counter(),
                test_connection=TestConnections().openrouter,
                pricing={
                    TokenDirection.ENCODE: 0.000001,
                    TokenDirection.DECODE: 0.000002,
                },
            ),
            'nousresearch/nous-hermes-2-mixtral-8x7b-dpo': ModelConfig(
                client_class=OpenRouterAI,
                token_counter=TokenCounterFactory().create_openrouter_counter(),
                test_connection=TestConnections().openrouter,
                pricing={
                    TokenDirection.ENCODE: 0.0000006,
                    TokenDirection.DECODE: 0.0000006,
                },
            ),
            'mistralai/mistral-small': ModelConfig(
                client_class=OpenRouterAI,
                token_counter=TokenCounterFactory().create_openrouter_counter(),
                test_connection=TestConnections().openrouter,
                pricing={
                    TokenDirection.ENCODE: 0.0000002,
                    TokenDirection.DECODE: 0.0000006,
                },
            ),
            'mistralai/mistral-tiny': ModelConfig(
                client_class=OpenRouterAI,
                token_counter=TokenCounterFactory().create_openrouter_counter(),
                test_connection=TestConnections().openrouter,
                pricing={
                    TokenDirection.ENCODE: 0.00000025,
                    TokenDirection.DECODE: 0.00000025,
                },
            ),
            'mistralai/mixtral-8x7b-instruct': ModelConfig(
                client_class=OpenRouterAI,
                token_counter=TokenCounterFactory().create_openrouter_counter(),
                test_connection=TestConnections().openrouter,
                pricing={
                    TokenDirection.ENCODE: 0.00000008,
                    TokenDirection.DECODE: 0.00000024,
                },
            ),
            'neversleep/noromaid-20b': ModelConfig(
                client_class=OpenRouterAI,
                token_counter=TokenCounterFactory().create_openrouter_counter(),
                test_connection=TestConnections().openrouter,
                pricing={
                    TokenDirection.ENCODE: 0.000001,
                    TokenDirection.DECODE: 0.00000175,
                },
            ),
            'alpindale/goliath-120b': ModelConfig(
                client_class=OpenRouterAI,
                token_counter=TokenCounterFactory().create_openrouter_counter(),
                test_connection=TestConnections().openrouter,
                pricing={
                    TokenDirection.ENCODE: 0.000004,
                    TokenDirection.DECODE: 0.0000055,
                },
            ),
            'openrouter/auto': ModelConfig(
                client_class=OpenRouterAI,
                token_counter=TokenCounterFactory().create_openrouter_counter(),
                test_connection=TestConnections().openrouter,
                pricing={
                    TokenDirection.ENCODE: -1,
                    TokenDirection.DECODE: -1,
                },
            ),
            'openai/gpt-4-1106-preview': ModelConfig(
                client_class=OpenRouterAI,
                token_counter=TokenCounterFactory().create_openrouter_counter(),
                test_connection=TestConnections().openrouter,
                pricing={
                    TokenDirection.ENCODE: 0.00001,
                    TokenDirection.DECODE: 0.00003,
                },
            ),
            'openai/gpt-3.5-turbo-instruct': ModelConfig(
                client_class=OpenRouterAI,
                token_counter=TokenCounterFactory().create_openrouter_counter(),
                test_connection=TestConnections().openrouter,
                pricing={
                    TokenDirection.ENCODE: 0.0000015,
                    TokenDirection.DECODE: 0.000002,
                },
            ),
            'mistralai/mistral-7b-instruct-v0.1': ModelConfig(
                client_class=OpenRouterAI,
                token_counter=TokenCounterFactory().create_openrouter_counter(),
                test_connection=TestConnections().openrouter,
                pricing={
                    TokenDirection.ENCODE: 0.00000011,
                    TokenDirection.DECODE: 0.00000019,
                },
            ),
            'pygmalionai/mythalion-13b': ModelConfig(
                client_class=OpenRouterAI,
                token_counter=TokenCounterFactory().create_openrouter_counter(),
                test_connection=TestConnections().openrouter,
                pricing={
                    TokenDirection.ENCODE: 0.0000007,
                    TokenDirection.DECODE: 0.0000011,
                },
            ),
            'openai/gpt-3.5-turbo-16k': ModelConfig(
                client_class=OpenRouterAI,
                token_counter=TokenCounterFactory().create_openrouter_counter(),
                test_connection=TestConnections().openrouter,
                pricing={
                    TokenDirection.ENCODE: 0.000003,
                    TokenDirection.DECODE: 0.000004,
                },
            ),
            'mancer/weaver': ModelConfig(
                client_class=OpenRouterAI,
                token_counter=TokenCounterFactory().create_openrouter_counter(),
                test_connection=TestConnections().openrouter,
                pricing={
                    TokenDirection.ENCODE: 0.000001125,
                    TokenDirection.DECODE: 0.000001125,
                },
            ),
            'undi95/remm-slerp-l2-13b': ModelConfig(
                client_class=OpenRouterAI,
                token_counter=TokenCounterFactory().create_openrouter_counter(),
                test_connection=TestConnections().openrouter,
                pricing={
                    TokenDirection.ENCODE: 0.00000045,
                    TokenDirection.DECODE: 0.00000065,
                },
            ),
            'gryphe/mythomax-l2-13b': ModelConfig(
                client_class=OpenRouterAI,
                token_counter=TokenCounterFactory().create_openrouter_counter(),
                test_connection=TestConnections().openrouter,
                pricing={
                    TokenDirection.ENCODE: 0.00000006,
                    TokenDirection.DECODE: 0.00000006,
                },
            ),
            'openai/gpt-4': ModelConfig(
                client_class=OpenRouterAI,
                token_counter=TokenCounterFactory().create_openrouter_counter(),
                test_connection=TestConnections().openrouter,
                pricing={
                    TokenDirection.ENCODE: 0.00003,
                    TokenDirection.DECODE: 0.00006,
                },
            ),
            'openai/gpt-4-0314': ModelConfig(
                client_class=OpenRouterAI,
                token_counter=TokenCounterFactory().create_openrouter_counter(),
                test_connection=TestConnections().openrouter,
                pricing={
                    TokenDirection.ENCODE: 0.00003,
                    TokenDirection.DECODE: 0.00006,
                },
            ),
            'openai/gpt-3.5-turbo': ModelConfig(
                client_class=OpenRouterAI,
                token_counter=TokenCounterFactory().create_openrouter_counter(),
                test_connection=TestConnections().openrouter,
                pricing={
                    TokenDirection.ENCODE: 0.0000005,
                    TokenDirection.DECODE: 0.0000015,
                },
            ),
        }
